@@ -47,6 +47,7 @@
 
 #include <macros.h>
 #include <geometry/geometry_utils.h>
+#include <thread_pool.h>
 
 #include <profile.h>
 #include <trace_helpers.h>
@@ -259,11 +260,17 @@ OPENGL_GAL::OPENGL_GAL( GAL_DISPLAY_OPTIONS& aDisplayOptions, wxWindow* aParent,
     {
         m_glMainContext = GL_CONTEXT_MANAGER::Get().CreateCtx( this );
 
+        if( !m_glMainContext )
+            throw std::runtime_error( "Could not create the main OpenGL context" );
+
         m_glPrivContext = m_glMainContext;
     }
     else
     {
         m_glPrivContext = GL_CONTEXT_MANAGER::Get().CreateCtx( this, m_glMainContext );
+
+        if( !m_glPrivContext )
+            throw std::runtime_error( "Could not create a private OpenGL context" );
     }
 
     m_shader = new SHADER();
@@ -1418,21 +1425,23 @@ void OPENGL_GAL::DrawBitmap( const BITMAP_BASE& aBitmap, double alphaBlend )
     glActiveTexture( GL_TEXTURE0 );
     glBindTexture( GL_TEXTURE_2D, texture_id );
 
-    float texStartX = aBitmap.IsMirrored() ? 1.0 : 0.0;
-    float texEndX   = aBitmap.IsMirrored() ? 0.0 : 1.0;
+    float texStartX = aBitmap.IsMirroredX() ? 1.0 : 0.0;
+    float texEndX   = aBitmap.IsMirroredX() ? 0.0 : 1.0;
+    float texStartY = aBitmap.IsMirroredY() ? 1.0 : 0.0;
+    float texEndY   = aBitmap.IsMirroredY() ? 0.0 : 1.0;
 
     glBegin( GL_QUADS );
     glColor4f( 1.0, 1.0, 1.0, alpha );
-    glTexCoord2f( texStartX, 0.0 );
+    glTexCoord2f( texStartX, texStartY );
     glVertex3f( v0.x, v0.y, m_layerDepth );
     glColor4f( 1.0, 1.0, 1.0, alpha );
-    glTexCoord2f( texEndX, 0.0 );
+    glTexCoord2f( texEndX,  texStartY);
     glVertex3f( v1.x, v0.y, m_layerDepth );
     glColor4f( 1.0, 1.0, 1.0, alpha );
-    glTexCoord2f( texEndX, 1.0 );
+    glTexCoord2f( texEndX, texEndY);
     glVertex3f( v1.x, v1.y, m_layerDepth );
     glColor4f( 1.0, 1.0, 1.0, alpha );
-    glTexCoord2f( texStartX, 1.0 );
+    glTexCoord2f( texStartX, texEndY);
     glVertex3f( v0.x, v1.y, m_layerDepth );
     glEnd();
 
@@ -2530,16 +2539,8 @@ void OPENGL_GAL::init()
 #endif /* wxCHECK_VERSION( 3, 0, 3 ) */
 
     // Check correct initialization from the constructor
-    if( !m_glMainContext )
-        throw std::runtime_error( "Could not create the main OpenGL context" );
-
-    if( !m_glPrivContext )
-        throw std::runtime_error( "Could not create a private OpenGL context" );
-
     if( m_tesselator == nullptr )
-        throw std::runtime_error( "Could not create the m_tesselator" );
-    // End initialization checks
-
+        throw std::runtime_error( "Could not create the tesselator" );
     GLenum err = glewInit();
 
     if( GLEW_OK != err )
@@ -2779,15 +2780,31 @@ void OPENGL_GAL::DrawGlyphs( const std::vector<std::unique_ptr<KIFONT::GLYPH>>&
         // Optimized path for stroke fonts that pre-reserves glyph triangles.
         int triangleCount = 0;
 
+        if( aGlyphs.size() > 0 )
+        {
+            thread_pool& tp = GetKiCadThreadPool();
+
+            tp.push_loop( aGlyphs.size(),
+                    [&]( const int a, const int b)
+                    {
+                        for( int ii = a; ii < b; ++ii )
+                        {
+                            auto glyph = static_cast<KIFONT::OUTLINE_GLYPH*>( aGlyphs.at( ii ).get() );
+
+                            // Only call CacheTriangulation() if it has never been done before.
+                            // Otherwise we'll hash the triangulation to see if it has been edited,
+                            // and all our glpyh editing ops update the triangulation anyway.
+                            if( glyph->TriangulatedPolyCount() == 0 )
+                                glyph->CacheTriangulation( false );
+                        }
+                    } );
+            tp.wait_for_tasks();
+        }
+
         for( const std::unique_ptr<KIFONT::GLYPH>& glyph : aGlyphs )
         {
             const auto& outlineGlyph = static_cast<const KIFONT::OUTLINE_GLYPH&>( *glyph );
 
-            // Only call CacheTriangulation if it has never been done before.  Otherwise we'll hash
-            // the triangulation to see if it has been edited, and glyphs after creation are read-only.
-            if( outlineGlyph.TriangulatedPolyCount() == 0 )
-                const_cast<KIFONT::OUTLINE_GLYPH&>( outlineGlyph ).CacheTriangulation( false );
-
             for( unsigned int i = 0; i < outlineGlyph.TriangulatedPolyCount(); i++ )
             {
                 const SHAPE_POLY_SET::TRIANGULATED_POLYGON* polygon =
