@@ -43,6 +43,7 @@
 #include <wx/tooltip.h>
 
 #include <advanced_config.h>
+#include <cli/cli_names.h> // Needed for the pre wx 3.2 cli workaround
 #include <common.h>
 #include <config_params.h>
 #include <confirm.h>
@@ -51,8 +52,9 @@
 #include <eda_draw_frame.h>
 #include <gestfich.h>
 #include <id.h>
+#include <kicad_curl/kicad_curl.h>
 #include <kiplatform/policy.h>
-#include <lockfile.h>
+#include <macros.h>
 #include <menus_helpers.h>
 #include <paths.h>
 #include <pgm_base.h>
@@ -150,6 +152,8 @@ PGM_BASE::~PGM_BASE()
 
 void PGM_BASE::Destroy()
 {
+    KICAD_CURL::Cleanup();
+
 #ifdef KICAD_USE_SENTRY
     sentry_close();
 #endif
@@ -408,6 +412,8 @@ bool PGM_BASE::InitPgm( bool aHeadless, bool aSkipPyInit, bool aIsUnitTest )
     // In particular, the user cache path is the most likely to be hit by startup code
     PATHS::EnsureUserPathsExist();
 
+    KICAD_CURL::Init();
+
 #ifdef KICAD_USE_SENTRY
     sentryInit();
 #endif
@@ -874,4 +880,36 @@ bool PGM_BASE::IsGUI()
     bool run_gui = wxTheApp->GetClassName() != KICAD_CLI_APP_NAME;
     return run_gui;
 #endif
-}
\ No newline at end of file
+}
+
+
+void PGM_BASE::HandleException( std::exception_ptr aPtr )
+{
+    try
+    {
+        if( aPtr )
+            std::rethrow_exception( aPtr );
+    }
+    catch( const IO_ERROR& ioe )
+    {
+        wxLogError( ioe.What() );
+    }
+    catch( const std::exception& e )
+    {
+#ifdef KICAD_USE_SENTRY
+        sentry_value_t exc = sentry_value_new_exception( "exception", e.what() );
+        sentry_value_set_stacktrace( exc, NULL, 0 );
+
+        sentry_value_t sentryEvent = sentry_value_new_event();
+        sentry_event_add_exception( sentryEvent, exc );
+        sentry_capture_event( sentryEvent );
+#endif
+
+        wxLogError( wxT( "Unhandled exception class: %s  what: %s" ),
+                    FROM_UTF8( typeid( e ).name() ), FROM_UTF8( e.what() ) );
+    }
+    catch( ... )
+    {
+        wxLogError( wxT( "Unhandled exception of unknown type" ) );
+    }
+}
