@@ -75,7 +75,7 @@ DIALOG_CHANGE_SYMBOLS::DIALOG_CHANGE_SYMBOLS( SCH_EDIT_FRAME* aParent, SCH_SYMBO
 
         m_newId->ChangeValue( UnescapeString( m_symbol->GetLibId().Format() ) );
         m_specifiedReference->ChangeValue( m_symbol->GetRef( currentSheet ) );
-        m_specifiedValue->ChangeValue( m_symbol->GetValueFieldText( false ) );
+        m_specifiedValue->ChangeValue( UnescapeString( m_symbol->GetField( VALUE_FIELD )->GetText() ) );
         m_specifiedId->ChangeValue( UnescapeString( m_symbol->GetLibId().Format() ) );
     }
     else
@@ -426,12 +426,14 @@ bool DIALOG_CHANGE_SYMBOLS::isMatch( SCH_SYMBOL* aSymbol, SCH_SHEET_PATH* aInsta
     else if( m_matchByReference->GetValue() )
     {
         return WildCompareString( m_specifiedReference->GetValue(),
-                                  aSymbol->GetRef( aInstance, false ), false );
+                                  UnescapeString( aSymbol->GetRef( aInstance, false ) ),
+                                  false );
     }
     else if( m_matchByValue->GetValue() )
     {
         return WildCompareString( m_specifiedValue->GetValue(),
-                                  aSymbol->GetValueFieldText( false ), false );
+                                  UnescapeString( aSymbol->GetField( VALUE_FIELD )->GetText() ),
+                                  false );
     }
     else if( m_matchById )
     {
@@ -589,8 +591,10 @@ int DIALOG_CHANGE_SYMBOLS::processSymbols( const std::map<SCH_SYMBOL*,
 
         if( m_resetAttributes->GetValue() )
         {
-            symbol->SetIncludeInBom( libSymbol->GetIncludeInBom() );
-            symbol->SetIncludeOnBoard( libSymbol->GetIncludeOnBoard() );
+            // Fetch the attributes from the *flattened* library symbol.  They are not supported
+            // in derived symbols.
+            symbol->SetIncludeInBom( symbol->GetLibSymbolRef()->GetIncludeInBom() );
+            symbol->SetIncludeOnBoard( symbol->GetLibSymbolRef()->GetIncludeOnBoard() );
         }
 
         bool removeExtras = m_removeExtraBox->GetValue();
@@ -609,9 +613,9 @@ int DIALOG_CHANGE_SYMBOLS::processSymbols( const std::map<SCH_SYMBOL*,
                 continue;
 
             if( i < MANDATORY_FIELDS )
-                libField = libSymbol->GetFieldById( (int) i );
+                libField = symbol->GetLibSymbolRef()->GetFieldById( (int) i );
             else
-                libField = libSymbol->FindField( field.GetName() );
+                libField = symbol->GetLibSymbolRef()->FindField( field.GetName() );
 
             if( libField )
             {
@@ -670,7 +674,7 @@ int DIALOG_CHANGE_SYMBOLS::processSymbols( const std::map<SCH_SYMBOL*,
         }
 
         std::vector<LIB_FIELD*> libFields;
-        libSymbol->GetFields( libFields );
+        symbol->GetLibSymbolRef()->GetFields( libFields );
 
         for( unsigned i = MANDATORY_FIELDS; i < libFields.size(); ++i )
         {
