@@ -1,7 +1,7 @@
 /*
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
- * Copyright (C) 2019-2022 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2019-2023 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -202,9 +202,9 @@ bool DIALOG_GLOBAL_EDIT_TEXT_AND_GRAPHICS::TransferDataToWindow()
         m_netFilter->SetValue( g_netFilter );
         m_netFilterOpt->SetValue( true );
     }
-    else if( m_parent->GetHighlightedConnection() )
+    else if( !m_parent->GetHighlightedConnection().IsEmpty() )
     {
-        m_netFilter->SetValue( m_parent->GetHighlightedConnection()->Name() );
+        m_netFilter->SetValue( m_parent->GetHighlightedConnection() );
     }
     else if( m_selection.GetSize() )
     {
