@@ -371,6 +371,7 @@ bool SCH_PRINTOUT::OnPrintPage( int page )
     m_parent->SetCurrentSheet( sheetList[ page - 1 ] );
     m_parent->GetCurrentSheet().UpdateAllScreenReferences();
     m_parent->SetSheetNumberAndCount();
+    m_parent->RecomputeIntersheetRefs();
     screen = m_parent->GetCurrentSheet().LastScreen();
     PrintPage( screen );
     m_parent->SetCurrentSheet( oldsheetpath );
@@ -430,7 +431,7 @@ void SCH_PRINTOUT::PrintPage( SCH_SCREEN* aScreen )
     COLOR_SETTINGS*    theme = mgr.GetColorSettings( cfg->m_Printing.color_theme );
 
     // Change scale factor and offset to print the whole page.
-    bool printReference = cfg->m_Printing.title_block;
+    bool printDrawingSheet = cfg->m_Printing.title_block;
 
     pageSizeIU = aScreen->GetPageSettings().GetSizeIU( schIUScale.IU_PER_MILS );
     FitThisSizeToPaper( pageSizeIU );
@@ -519,7 +520,7 @@ void SCH_PRINTOUT::PrintPage( SCH_SCREEN* aScreen )
 
     renderSettings.SetDefaultFont( cfg->m_Appearance.default_font );
 
-    if( printReference )
+    if( printDrawingSheet )
     {
         m_parent->PrintDrawingSheet( &renderSettings, aScreen, aScreen->Schematic()->GetProperties(),
                                      schIUScale.IU_PER_MILS, aScreen->GetFileName(), wxEmptyString );
