@@ -115,8 +115,7 @@ END_EVENT_TABLE()
 
 SCH_EDIT_FRAME::SCH_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
         SCH_BASE_FRAME( aKiway, aParent, FRAME_SCH, wxT( "Eeschema" ), wxDefaultPosition,
-                        wxDefaultSize, KICAD_DEFAULT_DRAWFRAME_STYLE, SCH_EDIT_FRAME_NAME ),
-        m_highlightedConn( nullptr )
+                        wxDefaultSize, KICAD_DEFAULT_DRAWFRAME_STYLE, SCH_EDIT_FRAME_NAME )
 {
     m_maximizeByDefault = true;
     m_schematic = new SCHEMATIC( nullptr );
@@ -718,7 +717,7 @@ void SCH_EDIT_FRAME::HardRedraw()
     for( SCH_ITEM* item : screen->Items() )
         item->ClearCaches();
 
-    for( std::pair<const wxString, LIB_SYMBOL*>& libSymbol : screen->GetLibSymbols() )
+    for( const std::pair<const wxString, LIB_SYMBOL*>& libSymbol : screen->GetLibSymbols() )
     {
         wxCHECK2( libSymbol.second, continue );
         libSymbol.second->ClearCaches();
@@ -1016,22 +1015,25 @@ void SCH_EDIT_FRAME::ShowFindReplaceDialog( bool aReplace )
         switch( front->Type() )
         {
         case SCH_SYMBOL_T:
-            findString = static_cast<SCH_SYMBOL*>( front )->GetValueFieldText( true );
+        {
+            SCH_SYMBOL* symbol = static_cast<SCH_SYMBOL*>( front );
+            findString = UnescapeString( symbol->GetField( VALUE_FIELD )->GetText() );
             break;
+        }
 
         case SCH_FIELD_T:
-            findString = static_cast<SCH_FIELD*>( front )->GetShownText();
+            findString = UnescapeString( static_cast<SCH_FIELD*>( front )->GetText() );
             break;
 
         case SCH_LABEL_T:
         case SCH_GLOBAL_LABEL_T:
         case SCH_HIER_LABEL_T:
         case SCH_SHEET_PIN_T:
-            findString = static_cast<SCH_LABEL_BASE*>( front )->GetShownText();
+            findString = UnescapeString( static_cast<SCH_LABEL_BASE*>( front )->GetText() );
             break;
 
         case SCH_TEXT_T:
-            findString = static_cast<SCH_TEXT*>( front )->GetShownText();
+            findString = UnescapeString( static_cast<SCH_TEXT*>( front )->GetText() );
 
             if( findString.Contains( wxT( "\n" ) ) )
                 findString = findString.Before( '\n' );
@@ -1046,9 +1048,10 @@ void SCH_EDIT_FRAME::ShowFindReplaceDialog( bool aReplace )
     if( m_findReplaceDialog )
         m_findReplaceDialog->Destroy();
 
-    m_findReplaceDialog = new DIALOG_SCH_FIND(
-            this, static_cast<SCH_SEARCH_DATA*>( m_findReplaceData.get() ), wxDefaultPosition,
-            wxDefaultSize, aReplace ? wxFR_REPLACEDIALOG : 0 );
+    m_findReplaceDialog = new DIALOG_SCH_FIND( this,
+                                               static_cast<SCH_SEARCH_DATA*>( m_findReplaceData.get() ),
+                                               wxDefaultPosition, wxDefaultSize,
+                                               aReplace ? wxFR_REPLACEDIALOG : 0 );
 
     m_findReplaceDialog->SetFindEntries( m_findStringHistoryList, findString );
     m_findReplaceDialog->SetReplaceEntries( m_replaceStringHistoryList );
@@ -1438,18 +1441,11 @@ void SCH_EDIT_FRAME::initScreenZoom()
 
 void SCH_EDIT_FRAME::RecalculateConnections( SCH_CLEANUP_FLAGS aCleanupFlags )
 {
-    const SCH_CONNECTION* highlight       = GetHighlightedConnection();
-    SCH_ITEM*             highlightedItem = nullptr;
-    SCH_SHEET_PATH        highlightPath;
-
-    if( highlight )
-    {
-        highlightPath = highlight->LocalSheet();
-        highlightedItem = dynamic_cast<SCH_ITEM*>( GetItem( highlight->Parent()->m_Uuid ) );
-    }
-
+    bool                highlightedConnChanged = false;
+    wxString            highlightedConn = GetHighlightedConnection();
     SCHEMATIC_SETTINGS& settings = Schematic().Settings();
     SCH_SHEET_LIST      list = Schematic().GetSheets();
+
 #ifdef PROFILE
     PROF_TIMER timer;
 #endif
@@ -1477,9 +1473,92 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_CLEANUP_FLAGS aCleanupFlags )
             [&]( SCH_ITEM* aChangedItem ) -> void
             {
                 GetCanvas()->GetView()->Update( aChangedItem, KIGFX::REPAINT );
+
+                SCH_CONNECTION* connection = aChangedItem->Connection();
+
+                if( connection && ( connection->Name() == highlightedConn ) )
+                    highlightedConnChanged = true;
             };
 
-    Schematic().ConnectionGraph()->Recalculate( list, true, &changeHandler );
+    if( !ADVANCED_CFG::GetCfg().m_IncrementalConnectivity || aCleanupFlags == GLOBAL_CLEANUP
+            || m_undoList.m_CommandsList.empty() )
+    {
+        Schematic().ConnectionGraph()->Recalculate( list, true, &changeHandler );
+    }
+    else
+    {
+        auto& changed_list = m_undoList.m_CommandsList.back();
+        std::set<SCH_ITEM*> changed_items;
+        std::vector<VECTOR2I> pts;
+
+        for( unsigned ii = 0; ii < changed_list->GetCount(); ++ii )
+        {
+            EDA_ITEM* item = changed_list->GetPickedItem( ii );
+
+            if( !item || !IsEeschemaType( item->Type() ) )
+                continue;
+
+            SCH_ITEM* sch_item = static_cast<SCH_ITEM*>( item );
+
+            std::vector<VECTOR2I> tmp_pts = sch_item->GetConnectionPoints();
+            pts.insert( pts.end(), tmp_pts.begin(), tmp_pts.end() );
+            changed_items.insert( sch_item );
+        }
+
+        for( VECTOR2I& pt: pts )
+        {
+            for( SCH_ITEM* item : GetScreen()->Items().Overlapping(pt ) )
+            {
+                if( !item->IsConnectable() )
+                    continue;
+
+                if( SCH_LINE* line = dyn_cast<SCH_LINE*>( item ) )
+                {
+                    if( line->HitTest( pt ) )
+                    {
+                        changed_items.insert( item );
+                        continue;
+                    }
+                }
+
+                if( SCH_SYMBOL* sym = dyn_cast<SCH_SYMBOL*>( item ) )
+                {
+                    std::vector<SCH_PIN*> pins = sym->GetPins();
+                    changed_items.insert( pins.begin(), pins.end() );
+                    continue;
+                }
+
+                if( item->IsConnected( pt ) )
+                    changed_items.insert( item );
+            }
+        }
+
+        std::set<std::pair<SCH_SHEET_PATH, SCH_ITEM*>> all_items =
+                Schematic().ConnectionGraph()->ExtractAffectedItems(
+                        changed_items );
+
+        CONNECTION_GRAPH new_graph( &Schematic() );
+
+        new_graph.SetLastCodes( Schematic().ConnectionGraph() );
+
+        for( auto&[ path, item ] : all_items )
+        {
+            switch( item->Type() )
+            {
+            case SCH_FIELD_T:
+            case SCH_PIN_T:
+            case SCH_SHEET_PIN_T:
+                static_cast<SCH_ITEM*>( item->GetParent() )->SetConnectivityDirty();
+                break;
+
+            default:
+                item->SetConnectivityDirty();
+            }
+        }
+
+        new_graph.Recalculate( list, false, &changeHandler );
+        Schematic().ConnectionGraph()->Merge( new_graph );
+    }
 
     GetCanvas()->GetView()->UpdateAllItemsConditionally(
             [&]( KIGFX::VIEW_ITEM* aItem ) -> int
@@ -1525,8 +1604,13 @@ void SCH_EDIT_FRAME::RecalculateConnections( SCH_CLEANUP_FLAGS aCleanupFlags )
                 return flags;
             } );
 
-    if( highlightedItem )
-        SetHighlightedConnection( highlightedItem->Connection( &highlightPath ) );
+    if( !highlightedConn.IsEmpty() )
+    {
+        if( highlightedConnChanged )
+            wxLogDebug( wxS( "Highlighted connection \"%s\" changed." ), highlightedConn );
+        else if( !Schematic().ConnectionGraph()->FindFirstSubgraphByName( highlightedConn ) )
+            wxLogDebug( wxS( "Highlighted connection \"%s\" no longer exists." ), highlightedConn );
+    }
 }
 
 
@@ -1580,8 +1664,8 @@ void SCH_EDIT_FRAME::CommonSettingsChanged( bool aEnvVarsChanged, bool aTextVars
     for( SCH_ITEM* item : screen->Items() )
         item->ClearCaches();
 
-    for( std::pair<const wxString, LIB_SYMBOL*>& libSymbol : screen->GetLibSymbols() )
-        libSymbol.second->ClearCaches();
+    for( const auto& [ libItemName, libSymbol ] : screen->GetLibSymbols() )
+        libSymbol->ClearCaches();
 
     GetCanvas()->ForceRefresh();
 
@@ -1630,10 +1714,10 @@ void SCH_EDIT_FRAME::ShowChangedLanguage()
 
 void SCH_EDIT_FRAME::UpdateNetHighlightStatus()
 {
-    if( const SCH_CONNECTION* conn = GetHighlightedConnection() )
+    if( !GetHighlightedConnection().IsEmpty() )
     {
         SetStatusText( wxString::Format( _( "Highlighted net: %s" ),
-                                         UnescapeString( conn->Name() ) ) );
+                                         UnescapeString( GetHighlightedConnection() ) ) );
     }
     else
     {
@@ -1838,7 +1922,7 @@ void SCH_EDIT_FRAME::DisplayCurrentSheet()
 
     SCH_BASE_FRAME::SetScreen( screen );
 
-    m_toolManager->ResetTools( TOOL_BASE::MODEL_RELOAD );
+    m_toolManager->ResetTools( TOOL_BASE::REDRAW );
 
     // update the References
     GetCurrentSheet().UpdateAllScreenReferences();
