@@ -990,7 +990,7 @@ void SCH_PAINTER::draw( const LIB_FIELD *aField, int aLayer, bool aDimmed )
         if( drawingShadows )
             attrs.m_StrokeWidth += getShadowWidth( !aField->IsSelected() );
 
-        strokeText( UnescapeString( aField->GetShownText() ), textpos, attrs );
+        strokeText( UnescapeString( aField->GetShownText( true ) ), textpos, attrs );
     }
 
     // Draw the umbilical line when in the schematic editor
@@ -1041,7 +1041,7 @@ void SCH_PAINTER::draw( const LIB_TEXT* aText, int aLayer, bool aDimmed )
     }
     else
     {
-        wxString        shownText( aText->GetShownText() );
+        wxString        shownText( aText->GetShownText( true ) );
         VECTOR2D        pos = bBox.Centre();
         TEXT_ATTRIBUTES attrs = aText->GetAttributes();
 
@@ -1098,7 +1098,7 @@ void SCH_PAINTER::draw( const LIB_TEXTBOX* aTextBox, int aLayer, bool aDimmed )
     auto drawText =
             [&]()
             {
-                wxString        shownText = aTextBox->GetShownText();
+                wxString        shownText = aTextBox->GetShownText( true );
                 TEXT_ATTRIBUTES attrs = aTextBox->GetAttributes();
 
                 attrs.m_Angle = aTextBox->GetDrawRotation();
@@ -1526,15 +1526,14 @@ void SCH_PAINTER::draw( const LIB_PIN *aPin, int aLayer, bool aDimmed )
                 m_gal->SetFillColor( colour[i] );
 
                 TEXT_ATTRIBUTES attrs;
+                attrs.m_Font = KIFONT::FONT::GetFont( eeconfig()->m_Appearance.default_font );
                 attrs.m_Size = VECTOR2I( size[i], size[i] );
                 attrs.m_Halign = hAlign;
                 attrs.m_Valign = vAlign;
                 attrs.m_Angle = aAngle;
                 attrs.m_StrokeWidth = KiROUND( thickness[i] );
-                KIFONT::FONT* font = KIFONT::FONT::GetFont( eeconfig()->m_Appearance.default_font, attrs.m_Bold,
-                                                      attrs.m_Italic );
 
-                if( drawingShadows && !font->IsOutline() )
+                if( drawingShadows && !attrs.m_Font->IsOutline() )
                 {
                     strokeText( text[i], aPos, attrs );
                 }
@@ -1908,7 +1907,7 @@ void SCH_PAINTER::draw( const SCH_SHAPE* aShape, int aLayer )
 }
 
 
-void SCH_PAINTER::draw( const SCH_TEXT *aText, int aLayer )
+void SCH_PAINTER::draw( const SCH_TEXT* aText, int aLayer )
 {
     bool drawingShadows = aLayer == LAYER_SELECTION_SHADOWS;
     bool drawingDangling = aLayer == LAYER_DANGLING;
@@ -1962,7 +1961,7 @@ void SCH_PAINTER::draw( const SCH_TEXT *aText, int aLayer )
     m_gal->SetStrokeColor( color );
     m_gal->SetFillColor( color );
 
-    wxString        shownText( aText->GetShownText() );
+    wxString        shownText( aText->GetShownText( true ) );
     VECTOR2I        text_offset = aText->GetSchematicTextOffset( &m_schSettings );
     TEXT_ATTRIBUTES attrs = aText->GetAttributes();
     KIFONT::FONT*   font = getFont( aText );
@@ -1976,6 +1975,21 @@ void SCH_PAINTER::draw( const SCH_TEXT *aText, int aLayer )
         m_gal->SetIsStroke( true );
         attrs.m_StrokeWidth += getShadowWidth( !aText->IsSelected() );
         attrs.m_Underlined = false;
+
+        // Fudge factors to match 6.0 positioning
+        // New text stroking has width dependent offset but we need to
+        // center the shadow on the stroke.  NB this offset is in font.cpp also
+        double fudge = getShadowWidth( !aText->IsSelected() ) / 1.52;
+
+        if( attrs.m_Halign == GR_TEXT_H_ALIGN_LEFT && attrs.m_Angle == ANGLE_0 )
+            text_offset.x -= fudge;
+        else if( attrs.m_Halign == GR_TEXT_H_ALIGN_RIGHT && attrs.m_Angle == ANGLE_90 )
+            text_offset.y -= fudge;
+        else if( attrs.m_Halign == GR_TEXT_H_ALIGN_RIGHT && attrs.m_Angle == ANGLE_0 )
+            text_offset.x += fudge;
+        else if( attrs.m_Halign == GR_TEXT_H_ALIGN_LEFT && attrs.m_Angle == ANGLE_90 )
+            text_offset.y += fudge;
+
         strokeText( shownText, aText->GetDrawPos() + text_offset, attrs );
 
     }
@@ -2027,8 +2041,8 @@ void SCH_PAINTER::draw( const SCH_TEXT *aText, int aLayer )
 
             if( cache )
             {
-                for( const std::unique_ptr<KIFONT::GLYPH>& glyph : *cache )
-                    m_gal->DrawGlyph( *glyph );
+                m_gal->SetLineWidth( attrs.m_StrokeWidth );
+                m_gal->DrawGlyphs( *cache );
             }
             else
             {
@@ -2043,22 +2057,15 @@ void SCH_PAINTER::draw( const SCH_TEXT *aText, int aLayer )
 
 void SCH_PAINTER::draw( const SCH_TEXTBOX* aTextBox, int aLayer )
 {
-    bool    drawingShadows = aLayer == LAYER_SELECTION_SHADOWS;
-    COLOR4D color = getRenderColor( aTextBox, aLayer, drawingShadows );
-    float   borderWidth = getLineWidth( aTextBox, drawingShadows );
-
-    KIFONT::FONT* font = aTextBox->GetFont();
-
-    if( !font )
-    {
-        font = KIFONT::FONT::GetFont( m_schSettings.GetDefaultFont(), aTextBox->IsBold(),
-                                      aTextBox->IsItalic() );
-    }
+    bool          drawingShadows = aLayer == LAYER_SELECTION_SHADOWS;
+    COLOR4D       color = getRenderColor( aTextBox, aLayer, drawingShadows );
+    float         borderWidth = getLineWidth( aTextBox, drawingShadows );
+    KIFONT::FONT* font = getFont( aTextBox );
 
     auto drawText =
             [&]()
             {
-                wxString        shownText = aTextBox->GetShownText();
+                wxString        shownText = aTextBox->GetShownText( true );
                 TEXT_ATTRIBUTES attrs = aTextBox->GetAttributes();
 
                 attrs.m_Angle = aTextBox->GetDrawRotation();
@@ -2078,8 +2085,8 @@ void SCH_PAINTER::draw( const SCH_TEXTBOX* aTextBox, int aLayer )
 
                 if( cache )
                 {
-                    for( const std::unique_ptr<KIFONT::GLYPH>& glyph : *cache )
-                        m_gal->DrawGlyph( *glyph );
+                    m_gal->SetLineWidth( attrs.m_StrokeWidth );
+                    m_gal->DrawGlyphs( *cache );
                 }
                 else
                 {
@@ -2356,7 +2363,7 @@ void SCH_PAINTER::draw( const SCH_FIELD* aField, int aLayer, bool aDimmed )
             return;
     }
 
-    wxString shownText = aField->GetShownText();
+    wxString shownText = aField->GetShownText( true );
 
     if( shownText.IsEmpty() )
         return;
@@ -2451,8 +2458,8 @@ void SCH_PAINTER::draw( const SCH_FIELD* aField, int aLayer, bool aDimmed )
 
             if( cache )
             {
-                for( const std::unique_ptr<KIFONT::GLYPH>& glyph : *cache )
-                    m_gal->DrawGlyph( *glyph );
+                m_gal->SetLineWidth( attributes.m_StrokeWidth );
+                m_gal->DrawGlyphs( *cache );
             }
             else
             {
