@@ -376,8 +376,8 @@ void SCH_SEXPR_PLUGIN::Format( SCH_SHEET* aSheet )
     // Save cache library.
     m_out->Print( 1, "(lib_symbols\n" );
 
-    for( std::pair<const wxString, LIB_SYMBOL*>& libSymbol : screen->GetLibSymbols() )
-        SCH_SEXPR_PLUGIN_CACHE::SaveSymbol( libSymbol.second, *m_out, 2, libSymbol.first );
+    for( const auto& [ libItemName, libSymbol ] : screen->GetLibSymbols() )
+        SCH_SEXPR_PLUGIN_CACHE::SaveSymbol( libSymbol, *m_out, 2, libItemName );
 
     m_out->Print( 1, ")\n\n" );
 
@@ -397,7 +397,11 @@ void SCH_SEXPR_PLUGIN::Format( SCH_SHEET* aSheet )
     std::multiset<SCH_ITEM*, decltype( cmp )> save_map( cmp );
 
     for( SCH_ITEM* item : screen->Items() )
-        save_map.insert( item );
+    {
+        // Markers are not saved, so keep them from being considered below
+        if( item->Type() != SCH_MARKER_T )
+            save_map.insert( item );
+    }
 
     KICAD_T itemType = TYPE_NOT_INIT;
     SCH_LAYER_ID layer = SCH_LAYER_ID_START;
@@ -748,11 +752,11 @@ void SCH_SEXPR_PLUGIN::saveSymbol( SCH_SYMBOL* aSymbol, const SCHEMATIC& aSchema
             }
             else if( id == VALUE_FIELD )
             {
-                field.SetText( aSymbol->GetValueFieldText( false ) );
+                field.SetText( aSymbol->GetField( VALUE_FIELD )->GetText() );
             }
             else if( id == FOOTPRINT_FIELD )
             {
-                field.SetText( aSymbol->GetFootprintFieldText( false ) );
+                field.SetText( aSymbol->GetField( FOOTPRINT_FIELD )->GetText() );
             }
         }
 
@@ -1487,6 +1491,10 @@ LIB_SYMBOL* SCH_SEXPR_PLUGIN::LoadSymbol( const wxString& aLibraryPath, const wx
 
     LIB_SYMBOL_MAP::const_iterator it = m_cache->m_symbols.find( aSymbolName );
 
+    // We no longer escape '/' in symbol names, but we used to.
+    if( it == m_cache->m_symbols.end() && aSymbolName.Contains( '/' ) )
+        it = m_cache->m_symbols.find( EscapeString( aSymbolName, CTX_LEGACY_LIBID ) );
+
     if( it == m_cache->m_symbols.end() )
         return nullptr;
 
