@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2019 CERN
- * Copyright (C) 2019-2022 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2019-2023 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -221,7 +221,7 @@ bool EE_SELECTION_TOOL::Init()
             {
                 SCH_EDIT_FRAME* editFrame = dynamic_cast<SCH_EDIT_FRAME*>( m_frame );
 
-                return editFrame && editFrame->GetHighlightedConnection() != nullptr;
+                return editFrame && !editFrame->GetHighlightedConnection().IsEmpty();
             };
 
     auto haveSymbol =
@@ -355,10 +355,21 @@ int EE_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
 
         if( evt->IsMouseDown( BUT_LEFT ) )
         {
-            // Avoid triggering when running under other tools
-            // Distinguish point editor from selection modification by checking modifiers
-            if( m_frame->ToolStackIsEmpty() && m_toolMgr->GetTool<EE_POINT_EDITOR>()
-                && ( !m_toolMgr->GetTool<EE_POINT_EDITOR>()->HasPoint() || hasModifier() ) )
+            if( !m_frame->ToolStackIsEmpty() )
+            {
+                // Avoid triggering when running under other tools
+            }
+            else if( m_toolMgr->GetTool<EE_POINT_EDITOR>()
+                        && m_toolMgr->GetTool<EE_POINT_EDITOR>()->HasPoint() )
+            {
+                // Distinguish point editor from selection modification by checking modifiers
+                if( hasModifier() )
+                {
+                    m_originalCursor = m_toolMgr->GetMousePosition();
+                    m_disambiguateTimer.StartOnce( 500 );
+                }
+            }
+            else
             {
                 m_originalCursor = m_toolMgr->GetMousePosition();
                 m_disambiguateTimer.StartOnce( 500 );
@@ -572,6 +583,11 @@ int EE_SELECTION_TOOL::Main( const TOOL_EVENT& aEvent )
         {
             m_disambiguateTimer.Stop();
 
+            // We didn't set these, but we have reports that they leak out of some other tools,
+            // so we clear them here.
+            getViewControls()->SetAutoPan( false );
+            getViewControls()->CaptureCursor( false );
+
             if( SCH_EDIT_FRAME* schframe = dynamic_cast<SCH_EDIT_FRAME*>( m_frame ) )
                 schframe->FocusOnItem( nullptr );
 
@@ -1132,7 +1148,7 @@ void EE_SELECTION_TOOL::GuessSelectionCandidates( EE_COLLECTOR& collector, const
                     }
                 }
 
-                text->GetEffectiveTextShape()->Collide( poss, closestDist, &dist );
+                text->GetEffectiveTextShape( false )->Collide( poss, closestDist, &dist );
             }
             else if( symbol )
             {
