@@ -195,11 +195,10 @@ int SCH_DRAWING_TOOLS::PlaceSymbol( const TOOL_EVENT& aEvent )
 
                     if( cfg->m_AnnotatePanel.automatic || newReference.AlwaysAnnotate() )
                     {
-                        refs.ReannotateByOptions(
-                                (ANNOTATE_ORDER_T) cfg->m_AnnotatePanel.sort_order,
-                                (ANNOTATE_ALGO_T) cfg->m_AnnotatePanel.method,
-                                m_frame->Schematic().Settings().m_AnnotateStartNum, existingRefs,
-                                false, &hierarchy );
+                        refs.ReannotateByOptions( (ANNOTATE_ORDER_T) cfg->m_AnnotatePanel.sort_order,
+                                                  (ANNOTATE_ALGO_T) cfg->m_AnnotatePanel.method,
+                                                  m_frame->Schematic().Settings().m_AnnotateStartNum,
+                                                  existingRefs, false, &hierarchy );
 
                         refs.UpdateAnnotation();
 
@@ -1005,7 +1004,7 @@ SCH_TEXT* SCH_DRAWING_TOOLS::createNewText( const VECTOR2I& aPosition, int aType
     {
         DIALOG_TEXT_PROPERTIES dlg( m_frame, textItem );
 
-        // Must be quasi modal for syntax help
+        // QuasiModal required for syntax help and Scintilla auto-complete
         if( dlg.ShowQuasiModal() != wxID_OK )
         {
             delete textItem;
@@ -1403,6 +1402,7 @@ int SCH_DRAWING_TOOLS::TwoClickPlace( const TOOL_EVENT& aEvent )
                 {
                     getViewControls()->PinCursorInsideNonAutoscrollArea( true );
                     cursorPos = getViewControls()->GetMousePosition();
+                    cursorPos = grid.BestSnapAnchor( cursorPos, snapLayer, item );
                 }
 
                 if( item )
@@ -1609,6 +1609,7 @@ int SCH_DRAWING_TOOLS::DrawShape( const TOOL_EVENT& aEvent )
                 textbox->SetHorizJustify( m_lastTextJust );
                 textbox->SetStroke( m_lastTextboxStroke );
                 textbox->SetFillColor( m_lastTextboxFillColor );
+                textbox->SetParent( schematic );
 
                 item = textbox;
             }
@@ -1618,6 +1619,7 @@ int SCH_DRAWING_TOOLS::DrawShape( const TOOL_EVENT& aEvent )
 
                 item->SetStroke( m_lastStroke );
                 item->SetFillColor( m_lastFillColor );
+                item->SetParent( schematic );
             }
 
             item->SetFlags( IS_NEW );
@@ -1644,9 +1646,11 @@ int SCH_DRAWING_TOOLS::DrawShape( const TOOL_EVENT& aEvent )
                     SCH_TEXTBOX*           textbox = static_cast<SCH_TEXTBOX*>( item );
                     DIALOG_TEXT_PROPERTIES dlg( m_frame, textbox );
 
-                    // This is modal not quasi to protect against place symbol calls starting
-                    // TwoClickPlace wait routines in the middle
-                    if( dlg.ShowModal() != wxID_OK )
+                    getViewControls()->SetAutoPan( false );
+                    getViewControls()->CaptureCursor( false );
+
+                    // QuasiModal required for syntax help and Scintilla auto-complete
+                    if( dlg.ShowQuasiModal() != wxID_OK )
                     {
                         cleanup();
                         continue;
