@@ -754,15 +754,13 @@ int KICAD_MANAGER_CONTROL::ShowPlayer( const TOOL_EVENT& aEvent )
     }
     catch( const IO_ERROR& err )
     {
-        wxMessageBox( _( "Application failed to load:\n" ) + err.What(), _( "KiCad Error" ),
-                      wxOK | wxICON_ERROR, m_frame );
+        wxLogError( _( "Application failed to load:\n" ) + err.What() );
         return -1;
     }
 
     if ( !player )
     {
-        wxMessageBox( _( "Application failed to load." ), _( "KiCad Error" ),
-                      wxOK | wxICON_ERROR, m_frame );
+        wxLogError( _( "Application failed to load." ) );
         return -1;
     }
 
@@ -921,12 +919,10 @@ int KICAD_MANAGER_CONTROL::ShowPluginManager( const TOOL_EVENT& aEvent )
         KIWAY& kiway = m_frame->Kiway();
 
         // Reset state containing global lib tables
-        KIFACE* kiface;
-
-        if( kiface = kiway.KiFACE( KIWAY::FACE_SCH, false ) )
+        if( KIFACE* kiface = kiway.KiFACE( KIWAY::FACE_SCH, false ) )
             kiface->Reset();
 
-        if( kiface = kiway.KiFACE( KIWAY::FACE_PCB, false ) )
+        if( KIFACE* kiface = kiway.KiFACE( KIWAY::FACE_PCB, false ) )
             kiface->Reset();
 
         // Reload lib tables
