@@ -305,7 +305,7 @@ void BOARD::UpdateRatsnestExclusions()
 }
 
 
-std::vector<PCB_MARKER*> BOARD::ResolveDRCExclusions()
+std::vector<PCB_MARKER*> BOARD::ResolveDRCExclusions( bool aCreateMarkers )
 {
     for( PCB_MARKER* marker : GetBoard()->Markers() )
     {
@@ -320,28 +320,31 @@ std::vector<PCB_MARKER*> BOARD::ResolveDRCExclusions()
 
     std::vector<PCB_MARKER*> newMarkers;
 
-    for( const wxString& exclusionData : m_designSettings->m_DrcExclusions )
+    if( aCreateMarkers )
     {
-        PCB_MARKER* marker = PCB_MARKER::Deserialize( exclusionData );
-
-        if( !marker )
-            continue;
-
-        // Check to see if items still exist
-        for( const KIID& guid : marker->GetRCItem()->GetIDs() )
+        for( const wxString& exclusionData : m_designSettings->m_DrcExclusions )
         {
-            if( GetItem( guid ) == DELETED_BOARD_ITEM::GetInstance() )
+            PCB_MARKER* marker = PCB_MARKER::Deserialize( exclusionData );
+
+            if( !marker )
+                continue;
+
+            // Check to see if items still exist
+            for( const KIID& guid : marker->GetRCItem()->GetIDs() )
             {
-                delete marker;
-                marker = nullptr;
-                break;
+                if( GetItem( guid ) == DELETED_BOARD_ITEM::GetInstance() )
+                {
+                    delete marker;
+                    marker = nullptr;
+                    break;
+                }
             }
-        }
 
-        if( marker )
-        {
-            marker->SetExcluded( true );
-            newMarkers.push_back( marker );
+            if( marker )
+            {
+                marker->SetExcluded( true );
+                newMarkers.push_back( marker );
+            }
         }
     }
 
@@ -351,6 +354,24 @@ std::vector<PCB_MARKER*> BOARD::ResolveDRCExclusions()
 }
 
 
+void BOARD::GetContextualTextVars( wxArrayString* aVars ) const
+{
+    auto add =
+            [&]( const wxString& aVar )
+            {
+                if( !alg::contains( *aVars, aVar ) )
+                    aVars->push_back( aVar );
+            };
+
+    add( wxT( "LAYER" ) );
+
+    GetTitleBlock().GetContextualTextVars( aVars );
+
+    for( std::pair<wxString, wxString> entry : GetProject()->GetTextVars() )
+        add( entry.first );
+}
+
+
 bool BOARD::ResolveTextVar( wxString* token, int aDepth ) const
 {
     if( token->Contains( ':' ) )
@@ -1292,6 +1313,11 @@ BOX2I BOARD::ComputeBoundingBox( bool aBoardEdgesOnly ) const
     bool  showInvisibleText = IsElementVisible( LAYER_MOD_TEXT_INVISIBLE )
                                       && PgmOrNull() && !PgmOrNull()->m_Printing;
 
+    // If the board is just showing a footprint, we want all footprint layers
+    // included in the bounding box
+    if( IsFootprintHolder() )
+        visible.set();
+
     if( aBoardEdgesOnly )
         visible.set( Edge_Cuts );
 
@@ -2005,13 +2031,14 @@ ZONE* BOARD::AddArea( PICKED_ITEMS_LIST* aNewZonesList, int aNetcode, PCB_LAYER_
 
 
 bool BOARD::GetBoardPolygonOutlines( SHAPE_POLY_SET& aOutlines,
-                                     OUTLINE_ERROR_HANDLER* aErrorHandler )
+                                     OUTLINE_ERROR_HANDLER* aErrorHandler,
+                                     bool aAllowUseArcsInPolygons )
 {
     // max dist from one endPt to next startPt: use the current value
     int chainingEpsilon = GetOutlinesChainingEpsilon();
 
     bool success = BuildBoardPolygonOutlines( this, aOutlines, GetDesignSettings().m_MaxError,
-                                              chainingEpsilon, aErrorHandler );
+                                              chainingEpsilon, aErrorHandler, aAllowUseArcsInPolygons );
 
     // Make polygon strictly simple to avoid issues (especially in 3D viewer)
     aOutlines.Simplify( SHAPE_POLY_SET::PM_STRICTLY_SIMPLE );
@@ -2361,7 +2388,7 @@ void BOARD::ConvertBrdLayerToPolygonalContours( PCB_LAYER_ID aLayer,
         case PCB_TEXT_T:
         {
             const PCB_TEXT* text = static_cast<const PCB_TEXT*>( item );
-            text->TransformTextToPolySet( aOutlines, aLayer, 0, maxError, ERROR_INSIDE );
+            text->TransformTextToPolySet( aOutlines, 0, maxError, ERROR_INSIDE );
             break;
         }
 
@@ -2373,7 +2400,7 @@ void BOARD::ConvertBrdLayerToPolygonalContours( PCB_LAYER_ID aLayer,
             textbox->PCB_SHAPE::TransformShapeToPolygon( aOutlines, aLayer, 0, maxError,
                                                          ERROR_INSIDE );
             // plot text
-            textbox->TransformTextToPolySet( aOutlines, aLayer, 0, maxError, ERROR_INSIDE );
+            textbox->TransformTextToPolySet( aOutlines, 0, maxError, ERROR_INSIDE );
             break;
         }
 
