@@ -339,6 +339,7 @@ public:
     const std::map<wxString, wxString>& GetProperties() const { return m_properties; }
     void SetProperties( const std::map<wxString, wxString>& aProps ) { m_properties = aProps; }
 
+    void GetContextualTextVars( wxArrayString* aVars ) const;
     bool ResolveTextVar( wxString* token, int aDepth ) const;
 
     /// Visibility settings stored in board prior to 6.0, only used for loading legacy files
@@ -460,8 +461,12 @@ public:
 
     /**
      * Rebuild DRC markers from the serialized data in BOARD_DESIGN_SETTINGS.
+     *
+     * @param aCreateMarkers if true, create markers from serialized data; if false only
+     *                       use serialized data to set existing markers to excluded.
+     *                       The former is used on board load; the later after a DRC.
      */
-    std::vector<PCB_MARKER*> ResolveDRCExclusions();
+    std::vector<PCB_MARKER*> ResolveDRCExclusions( bool aCreateMarkers );
 
     /**
      * Update the visibility flags on the current unconnected ratsnest lines.
@@ -660,10 +665,14 @@ public:
      *
      * @param aOutlines is the #SHAPE_POLY_SET to fill in with outlines/holes.
      * @param aErrorHandler is an optional DRC_ITEM error handler.
+     * @param aAllowUseArcsInPolygons = an optional option to allow adding arcs in
+     *  SHAPE_LINE_CHAIN polylines/polygons when building outlines from aShapeList
+     *  This is mainly for export to STEP files
      * @return true if success, false if a contour is not valid
      */
     bool GetBoardPolygonOutlines( SHAPE_POLY_SET& aOutlines,
-                                  OUTLINE_ERROR_HANDLER* aErrorHandler = nullptr );
+                                  OUTLINE_ERROR_HANDLER* aErrorHandler = nullptr,
+                                  bool aAllowUseArcsInPolygons = false );
 
     /**
      * @return a epsilon value that is the max distance between 2 points to see them
