@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 2019 Jean-Pierre Charras, jp.charras at wanadoo.fr
- * Copyright (C) 2009-2022 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 2009-2023 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -51,6 +51,7 @@ struct BOARD_STACKUP_ROW_UI_ITEM
     int             m_SubItem;          // For multilayer dielectric, the index in sublayer list.
                                         // Must be >= 0 and < m_Item sublayer count. Used only for dielectic
                                         // 0 is the base list of parameters (always existing)
+    int             m_Row;              // The row number in the parent grid
     bool            m_isEnabled;        // True if the row is in board
                                         // false if not (this row is not shown on the panel)
     wxStaticBitmap* m_Icon;             // Color icon in first column (column 1)
@@ -66,10 +67,11 @@ struct BOARD_STACKUP_ROW_UI_ITEM
 
     COLOR4D         m_UserColor;        // User-specified color (if any)
 
-    BOARD_STACKUP_ROW_UI_ITEM( BOARD_STACKUP_ITEM* aItem, int aSubItem = 1 ) :
+    BOARD_STACKUP_ROW_UI_ITEM( BOARD_STACKUP_ITEM* aItem, int aSubItem, int aRow ) :
         m_Item( aItem ),
         m_SubItem( aSubItem ),
-        m_isEnabled( true ),
+        m_Row( aRow ),
+        m_isEnabled( false ),
         m_Icon( nullptr ),
         m_LayerName( nullptr ),
         m_LayerTypeCtrl( nullptr ),
@@ -87,7 +89,7 @@ struct BOARD_STACKUP_ROW_UI_ITEM
 class PANEL_SETUP_BOARD_STACKUP : public PANEL_SETUP_BOARD_STACKUP_BASE
 {
 public:
-    PANEL_SETUP_BOARD_STACKUP( PAGED_DIALOG* aParent, PCB_EDIT_FRAME* aFrame,
+    PANEL_SETUP_BOARD_STACKUP( wxWindow* aParentWindow, PCB_EDIT_FRAME* aFrame,
                                PANEL_SETUP_LAYERS* aPanelLayers );
     ~PANEL_SETUP_BOARD_STACKUP();
 
@@ -112,13 +114,11 @@ public:
     /// Return the color currently selected for the row aRow
     wxColor GetSelectedColor( int aRow ) const;
 
-    BOARD_STACKUP&  GetStackup() { return m_stackup; }
-
     // Called by wxWidgets: transfer current settings stored in m_stackup to the board
     bool TransferDataFromWindow() override;
 
 private:
-    /** Creates a BOARD_STACKUP_ROW_UI_ITEM relative to the aStackupItem.
+    /** Creates the controls in a BOARD_STACKUP_ROW_UI_ITEM relative to the aStackupItem.
      * @return a BOARD_STACKUP_ROW_UI_ITEM filled with corresponding widgets
      * @param aRow is the row index in the row list
      * @param aStackupItem is the stackup item controlled by the created
@@ -127,8 +127,7 @@ private:
      * this is the index of the sublayer to used inside aStackupItem
      * (from 0 to sub layer count - 1)
      */
-    BOARD_STACKUP_ROW_UI_ITEM createRowData( int aRow, BOARD_STACKUP_ITEM* aStackupItem,
-                                             int aSublayerIdx );
+    void lazyBuildRowUI( BOARD_STACKUP_ROW_UI_ITEM& ui_row_item );
 
     /** add a Spacer in m_fgGridSizer when a empty cell is needed
      */
@@ -230,42 +229,38 @@ private:
     wxBitmapComboBox* createColorBox( BOARD_STACKUP_ITEM* aStackupItem, int aRow );
 
     /**
-     * disconnect event handlers connected to wxControl items
-     * found in list m_controlItemsList
+     * disconnect event handlers connected to wxControl items found in list m_controlItemsList
      */
     void disconnectEvents();
 
 private:
     BOARD_STACKUP       m_stackup;
-    PANEL_SETUP_LAYERS* m_panelLayers;      // The associated PANEL_SETUP_LAYERS, to know
-                                            // enabled layers and copper layer names
-    LSET                m_enabledLayers;    // the current enabled layers in this panel
-                                            // restricted to allowed layers in stackup.
-                                            // when do not match the enabled layers
-                                            // in PANEL_SETUP_LAYERS the stackup is not up to date
-    // a list of currently available dielectric materials
-    DIELECTRIC_SUBSTRATE_LIST m_delectricMatList;
-    // a list of currently available solder mask materials
-    DIELECTRIC_SUBSTRATE_LIST m_solderMaskMatList;
-    // a list of currently available solder mask materials
-    DIELECTRIC_SUBSTRATE_LIST m_silkscreenMatList;
-    // List of items in m_fgGridSizer
-    std::vector<BOARD_STACKUP_ROW_UI_ITEM> m_rowUiItemsList;
+    PANEL_SETUP_LAYERS* m_panelLayers;      // The associated PANEL_SETUP_LAYERS, to know enabled
+                                            //   layers and copper layer names
+    LSET                m_enabledLayers;    // The current enabled layers in this panel restricted
+                                            //   to allowed layers in stackup.  (When this doesn't
+                                            //   match the enabled layers in PANEL_SETUP_LAYERS the
+                                            //   stackup is not up to date.)
 
-    PAGED_DIALOG*   m_parentDialog;
-    BOARD*          m_board;
+    DIELECTRIC_SUBSTRATE_LIST              m_delectricMatList;    // List of currently available
+                                                                  //   dielectric materials
+    DIELECTRIC_SUBSTRATE_LIST              m_solderMaskMatList;   // List of currently available
+                                                                  //   solder mask materials
+    DIELECTRIC_SUBSTRATE_LIST              m_silkscreenMatList;   // List of currently available
+                                                                  //   solder mask materials
+    std::vector<BOARD_STACKUP_ROW_UI_ITEM> m_rowUiItemsList;      // List of items in m_fgGridSizer
+
+    BOARD*                  m_board;
     BOARD_DESIGN_SETTINGS*  m_brdSettings;
-    PCB_EDIT_FRAME* m_frame;
-    wxSize          m_numericTextCtrlSize;  // Best size to enter values with units in wxTextCtrl
-    wxSize          m_numericFieldsSize;    // Best size to enter double values in wxTextCtrl
-    wxArrayString   m_core_prepreg_choice;  // Used to display the option list in dialog
-    wxSize          m_colorSwatchesSize;    // the size of color swatches in the wxBitmapComboBox.
-    wxSize          m_colorIconsSize;       // the size of color swatches in grid, left column.
+    PCB_EDIT_FRAME*         m_frame;
+    wxSize                  m_numericTextCtrlSize;  // Best size for wxTextCtrls with units
+    wxSize                  m_numericFieldsSize;    // Best size for wxTextCtrls without units
+    wxArrayString           m_core_prepreg_choice;  // Used to display the option list in dialog
+    wxSize                  m_colorSwatchesSize;    // Size of swatches in the wxBitmapComboBox.
+    wxSize                  m_colorIconsSize;       // Size of swatches in the grid (left column)
 
-    // The list of controls (wxChoice, wxBitmapComboBox, wxTextCtrl) added to the panel
-    // when building the BOARD_STACKUP_ITEM list editor and connected to command events
-    // Used to disconnect event handlers
-    std::vector<wxControl*> m_controlItemsList;
+    std::vector<wxControl*> m_controlItemsList;     // List of ctrls (wxChoice, wxTextCtrl, etc.)
+                                                    //   with added event handlers
 };
 
 #endif      // #ifndef PANEL_SETUP_BOARD_STACKUP_H
