@@ -26,18 +26,16 @@
 #include <widgets/font_choice.h>
 #include <dialog_text_properties.h>
 #include <confirm.h>
-#include <widgets/unit_binder.h>
 #include <board_commit.h>
 #include <board.h>
 #include <footprint.h>
-#include <string_utils.h>
 #include <pcb_text.h>
 #include <fp_text.h>
 #include <pcbnew.h>
+#include <project.h>
 #include <pcb_edit_frame.h>
 #include <pcb_layer_box_selector.h>
 #include <wx/valnum.h>
-#include <math/util.h>      // for KiROUND
 #include <scintilla_tricks.h>
 
 
@@ -98,6 +96,22 @@ DIALOG_TEXT_PROPERTIES::DIALOG_TEXT_PROPERTIES( PCB_BASE_EDIT_FRAME* aParent, BO
 
         // Do not allow locking items in the footprint editor
         m_cbLocked->Show( false );
+
+        m_tabOrder = {
+            m_SingleLineText,
+            m_LayerSelectionCtrl,
+            m_SizeXCtrl,
+            m_SizeYCtrl,
+            m_ThicknessCtrl,
+            m_Visible,
+            m_cbKnockout,
+            m_KeepUpright,
+            m_PositionXCtrl,
+            m_PositionYCtrl,
+            m_OrientCtrl,
+            m_sdbSizerOK,
+            m_sdbSizerCancel
+        };
     }
     else
     {
@@ -115,6 +129,21 @@ DIALOG_TEXT_PROPERTIES::DIALOG_TEXT_PROPERTIES( PCB_BASE_EDIT_FRAME* aParent, BO
 
         m_KeepUpright->Show( false );
         m_statusLine->Show( false );
+
+        m_tabOrder = {
+            m_MultiLineText,
+            m_cbLocked,
+            m_LayerSelectionCtrl,
+            m_SizeXCtrl,
+            m_SizeYCtrl,
+            m_ThicknessCtrl,
+            m_cbKnockout,
+            m_PositionXCtrl,
+            m_PositionYCtrl,
+            m_OrientCtrl,
+            m_sdbSizerOK,
+            m_sdbSizerCancel
+        };
     }
 
     m_bold->SetIsCheckButton();
@@ -177,6 +206,11 @@ DIALOG_TEXT_PROPERTIES::DIALOG_TEXT_PROPERTIES( PCB_BASE_EDIT_FRAME* aParent, BO
     Connect( wxEVT_CHAR_HOOK, wxKeyEventHandler( DIALOG_TEXT_PROPERTIES::OnCharHook ),
              nullptr, this );
 
+    m_MultiLineText->Bind( wxEVT_STC_CHARADDED,
+                           &DIALOG_TEXT_PROPERTIES::onScintillaCharAdded, this );
+    m_MultiLineText->Bind( wxEVT_STC_AUTOCOMP_CHAR_DELETED,
+                           &DIALOG_TEXT_PROPERTIES::onScintillaCharAdded, this );
+
     finishDialogSettings();
 }
 
@@ -219,6 +253,65 @@ void DIALOG_TEXT_PROPERTIES::OnSetFocusText( wxFocusEvent& event )
 }
 
 
+void DIALOG_TEXT_PROPERTIES::onScintillaCharAdded( wxStyledTextEvent &aEvent )
+{
+    wxStyledTextCtrl* te = m_MultiLineText;
+    wxArrayString     autocompleteTokens;
+    int               text_pos = te->GetCurrentPos();
+    int               start = te->WordStartPosition( text_pos, true );
+    wxString          partial;
+
+    auto textVarRef =
+            [&]( int pos )
+            {
+                return pos >= 2 && te->GetCharAt( pos-2 ) == '$' && te->GetCharAt( pos-1 ) == '{';
+            };
+
+    // Check for cross-reference
+    if( start > 1 && te->GetCharAt( start-1 ) == ':' )
+    {
+        int refStart = te->WordStartPosition( start-1, true );
+
+        if( textVarRef( refStart ) )
+        {
+            partial = te->GetRange( start, text_pos );
+
+            wxString ref = te->GetRange( refStart, start-1 );
+            BOARD*   board = m_item->GetBoard();
+
+            for( FOOTPRINT* candidate : board->Footprints() )
+            {
+                if( candidate->GetReference() == ref )
+                {
+                    candidate->GetContextualTextVars( &autocompleteTokens );
+                    break;
+                }
+            }
+        }
+    }
+    else if( textVarRef( start ) )
+    {
+        partial = te->GetTextRange( start, text_pos );
+
+        BOARD* board = m_item->GetBoard();
+
+        board->GetContextualTextVars( &autocompleteTokens );
+
+        if( m_fpText )
+        {
+            if( FOOTPRINT* footprint = static_cast<FOOTPRINT*>( m_fpText->GetParentFootprint() ) )
+                footprint->GetContextualTextVars( &autocompleteTokens );
+        }
+
+        for( std::pair<wxString, wxString> entry : board->GetProject()->GetTextVars() )
+            autocompleteTokens.push_back( entry.first );
+    }
+
+    m_scintillaTricks->DoAutocomplete( partial, autocompleteTokens );
+    m_MultiLineText->SetFocus();
+}
+
+
 bool DIALOG_TEXT_PROPERTIES::TransferDataToWindow()
 {
     if( m_SingleLineText->IsShown() )
