@@ -1389,6 +1389,13 @@ DRC_CONSTRAINT DRC_ENGINE::EvalRules( DRC_CONSTRAINT_T aConstraintType, const BO
             constraint.m_Value.SetMin( m_designSettings->m_MinClearance );
         }
 
+        if( a_is_non_copper || b_is_non_copper )
+        {
+            REPORT( _( "Board and netclass clearances apply only between copper items." ) );
+            constraint.m_Type = NULL_CONSTRAINT;
+            constraint.m_DisallowFlags = 0;
+        }
+
         return constraint;
     }
     else if( aConstraintType == DIFF_PAIR_GAP_CONSTRAINT )
