@@ -96,10 +96,14 @@ private:
 
     void testPadClearances();
 
+    void testGraphicClearances();
+
     void testZonesToZones();
 
     void testItemAgainstZone( BOARD_ITEM* aItem, ZONE* aZone, PCB_LAYER_ID aLayer );
 
+    void testKnockoutTextAgainstZone( BOARD_ITEM* aText, NETINFO_ITEM** aInheritedNet, ZONE* aZone );
+
     typedef struct checked
     {
         checked()
@@ -160,6 +164,14 @@ bool DRC_TEST_PROVIDER_COPPER_CLEARANCE::Run()
         testPadClearances();
     }
 
+    if( !m_drcEngine->IsErrorLimitExceeded( DRCE_CLEARANCE ) )
+    {
+        if( !reportPhase( _( "Checking copper graphic clearances..." ) ) )
+            return false;   // DRC cancelled
+
+        testGraphicClearances();
+    }
+
     if( !m_drcEngine->IsErrorLimitExceeded( DRCE_CLEARANCE ) )
     {
         if( !reportPhase( _( "Checking copper zone clearances..." ) ) )
@@ -431,6 +443,89 @@ void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testItemAgainstZone( BOARD_ITEM* aItem,
 }
 
 
+/*
+ * We have to special-case knockout text as it's most often knocked-out of a zone, so it's
+ * presumed to collide with one.  However, if it collides with more than one, and they have
+ * different nets, then we have a short.
+ */
+void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testKnockoutTextAgainstZone( BOARD_ITEM* aText,
+                                                                      NETINFO_ITEM** aInheritedNet,
+                                                                      ZONE* aZone )
+{
+    bool testClearance = !m_drcEngine->IsErrorLimitExceeded( DRCE_CLEARANCE );
+    bool testShorts = !m_drcEngine->IsErrorLimitExceeded( DRCE_SHORTING_ITEMS );
+
+    if( !testClearance && !testShorts )
+        return;
+
+    PCB_LAYER_ID layer = aText->GetLayer();
+
+    if( !aZone->GetLayerSet().test( layer ) )
+        return;
+
+    BOX2I itemBBox = aText->GetBoundingBox();
+    BOX2I worstCaseBBox = itemBBox;
+
+    worstCaseBBox.Inflate( m_board->m_DRCMaxClearance );
+
+    if( !worstCaseBBox.Intersects( aZone->GetBoundingBox() ) )
+        return;
+
+    DRC_RTREE*  zoneTree = m_board->m_CopperZoneRTreeCache[ aZone ].get();
+
+    if( !zoneTree )
+        return;
+
+    std::shared_ptr<SHAPE> itemShape = aText->GetEffectiveShape( layer, FLASHING::DEFAULT );
+
+    if( *aInheritedNet == nullptr )
+    {
+        if( zoneTree->QueryColliding( itemBBox, itemShape.get(), layer ) )
+            *aInheritedNet = aZone->GetNet();
+    }
+
+    if( *aInheritedNet == aZone->GetNet() )
+        return;
+
+    DRC_CONSTRAINT constraint = m_drcEngine->EvalRules( CLEARANCE_CONSTRAINT, aText, aZone, layer );
+    int            clearance = constraint.GetValue().Min();
+    int            actual;
+    VECTOR2I       pos;
+
+    if( constraint.GetSeverity() != RPT_SEVERITY_IGNORE && clearance >= 0 )
+    {
+        if( zoneTree->QueryColliding( itemBBox, itemShape.get(), layer,
+                                      std::max( 0, clearance - m_drcEpsilon ), &actual, &pos ) )
+        {
+            std::shared_ptr<DRC_ITEM> drce;
+            wxString                  msg;
+
+            if( testShorts && actual == 0 && *aInheritedNet )
+            {
+                drce = DRC_ITEM::Create( DRCE_SHORTING_ITEMS );
+                msg.Printf( _( "(nets %s and %s)" ),
+                              ( *aInheritedNet )->GetNetname(),
+                              aZone->GetNetname() );
+            }
+            else
+            {
+                drce = DRC_ITEM::Create( DRCE_CLEARANCE );
+                msg = formatMsg( _( "(%s clearance %s; actual %s)" ),
+                                 constraint.GetName(),
+                                 clearance,
+                                 actual );
+            }
+
+            drce->SetErrorMessage( drce->GetErrorText() + wxS( " " ) + msg );
+            drce->SetItems( aText, aZone );
+            drce->SetViolatingRule( constraint.GetParentRule() );
+
+            reportViolation( drce, pos, layer );
+        }
+    }
+}
+
+
 void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testTrackClearances()
 {
     // This is the number of tests between 2 calls to the progress bar
@@ -815,7 +910,7 @@ void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testPadClearances( )
                 }
             }
 
-            if( !reportProgress( ii++, count, progressDelta ) )
+            if( !reportProgress( ii++, (int) count, progressDelta ) )
                 return;
         }
 
@@ -825,6 +920,72 @@ void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testPadClearances( )
 }
 
 
+void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testGraphicClearances( )
+{
+    const int progressDelta = 100;
+    size_t    count = m_board->Drawings().size();
+    int       ii = 0;
+
+    for( FOOTPRINT* footprint : m_board->Footprints() )
+        count += footprint->GraphicalItems().size();
+
+    reportAux( wxT( "Testing %d graphics..." ), count );
+
+    auto isKnockoutText =
+            []( BOARD_ITEM* item )
+            {
+                if( item->Type() == PCB_TEXT_T )
+                    return static_cast<PCB_TEXT*>( item )->IsKnockout();
+                else if( item->Type() == PCB_FP_TEXT_T )
+                    return static_cast<FP_TEXT*>( item )->IsKnockout();
+                else
+                    return false;
+            };
+
+    auto testGraphicAgainstZone =
+            [&]( BOARD_ITEM* item )
+            {
+                if( !IsCopperLayer( item->GetLayer() ) )
+                    return;
+
+                // Knockout text is most often knocked-out of a zone, so it's presumed to
+                // collide with one.  However, if it collides with more than one, and they
+                // have different nets, then we have a short.
+                NETINFO_ITEM* inheritedNet = nullptr;
+
+                for( ZONE* zone : m_board->m_DRCCopperZones )
+                {
+                    if( isKnockoutText( item ) )
+                        testKnockoutTextAgainstZone( item, &inheritedNet, zone );
+                    else
+                        testItemAgainstZone( item, zone, item->GetLayer() );
+
+                    if( m_drcEngine->IsCancelled() )
+                        return;
+                }
+            };
+
+    for( BOARD_ITEM* item : m_board->Drawings() )
+    {
+        testGraphicAgainstZone( item );
+
+        if( !reportProgress( ii++, (int) count, progressDelta ) )
+            return;
+    }
+
+    for( FOOTPRINT* footprint : m_board->Footprints() )
+    {
+        for( BOARD_ITEM* item : footprint->GraphicalItems() )
+        {
+            testGraphicAgainstZone( item );
+
+            if( !reportProgress( ii++, (int) count, progressDelta ) )
+                return;
+        }
+    }
+}
+
+
 void DRC_TEST_PROVIDER_COPPER_CLEARANCE::testZonesToZones()
 {
     const int progressDelta = 50;
