@@ -23,6 +23,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
+#include <string>
+
 #include <confirm.h>
 #include <core/arraydim.h>
 #include <gestfich.h>
@@ -63,6 +65,8 @@
 #include "zone_filler.h"
 #include <wx_filename.h>  // For ::ResolvePossibleSymlinks()
 
+#include <kiplatform/io.h>
+
 #include <wx/wupdlock.h>
 #include <wx/filedlg.h>
 #include <wx/wfstream.h>
@@ -605,14 +609,17 @@ bool PCB_EDIT_FRAME::OpenProjectFiles( const std::vector<wxString>& aFileSet, in
     // We insist on caller sending us an absolute path, if it does not, we say it's a bug.
     wxASSERT_MSG( wx_filename.IsAbsolute(), wxT( "Path is not absolute!" ) );
 
-    std::unique_ptr<wxSingleInstanceChecker> lockFile = ::LockFile( fullFileName );
+    std::unique_ptr<LOCKFILE> lock = std::make_unique<LOCKFILE>( fullFileName );
 
-    if( !lockFile || lockFile->IsAnotherRunning() )
+    if( !lock->Locked() )
     {
-        msg.Printf( _( "PCB '%s' is already open." ), wx_filename.GetFullName() );
+        msg.Printf( _( "PCB '%s' is already open by '%s' at '%s'." ), wx_filename.GetFullName(),
+                lock->GetUsername(), lock->GetHostname() );
 
         if( !OverrideLock( this, msg ) )
             return false;
+
+        lock->OverrideLock();
     }
 
     if( IsContentModified() )
@@ -627,9 +634,6 @@ bool PCB_EDIT_FRAME::OpenProjectFiles( const std::vector<wxString>& aFileSet, in
         }
     }
 
-    // Release the lock file, until the new file is actually loaded
-    ReleaseFile();
-
     wxFileName pro = fullFileName;
     pro.SetExt( ProjectFileExtension );
 
@@ -830,7 +834,7 @@ bool PCB_EDIT_FRAME::OpenProjectFiles( const std::vector<wxString>& aFileSet, in
 
         // we should not ask PLUGINs to do these items:
         loadedBoard->BuildListOfNets();
-        ResolveDRCExclusions();
+        ResolveDRCExclusions( true );
         m_toolManager->RunAction( PCB_ACTIONS::repairBoard, true, true);
 
         if( loadedBoard->IsModified() )
@@ -950,7 +954,7 @@ bool PCB_EDIT_FRAME::OpenProjectFiles( const std::vector<wxString>& aFileSet, in
     }
 
     // Lock the file newly opened:
-    m_file_checker.reset( lockFile.release() );
+    m_file_checker.reset( lock.release() );
 
     if( !converted )
         UpdateFileHistory( GetBoard()->GetFileName() );
@@ -1101,6 +1105,9 @@ bool PCB_EDIT_FRAME::SavePcbFile( const wxString& aFileName, bool addToHistory,
         return false;
     }
 
+    // Preserve the permissions of the current file
+    KIPLATFORM::IO::DuplicatePermissions( pcbFileName.GetFullPath(), tempFile );
+
     // If save succeeded, replace the original with what we just wrote
     if( !wxRenameFile( tempFile, pcbFileName.GetFullPath() ) )
     {
