@@ -498,12 +498,12 @@ bool FOOTPRINT::ResolveTextVar( wxString* token, int aDepth ) const
 
     if( token->IsSameAs( wxT( "REFERENCE" ) ) )
     {
-        *token = m_reference->GetShownText( aDepth + 1 );
+        *token = m_reference->GetShownText( false, aDepth + 1 );
         return true;
     }
     else if( token->IsSameAs( wxT( "VALUE" ) ) )
     {
-        *token = m_value->GetShownText( aDepth + 1 );
+        *token = m_value->GetShownText( false, aDepth + 1 );
         return true;
     }
     else if( token->IsSameAs( wxT( "LAYER" ) ) )
@@ -1027,7 +1027,9 @@ void FOOTPRINT::GetMsgPanelInfo( EDA_DRAW_FRAME* aFrame, std::vector<MSG_PANEL_I
 {
     wxString msg, msg2;
 
-    aList.emplace_back( m_reference->GetShownText(), m_value->GetShownText() );
+    // Don't use GetShownText(); we want to see the variable references here
+    aList.emplace_back( UnescapeString( m_reference->GetText() ),
+                        UnescapeString( m_value->GetText() ) );
 
     if( aFrame->IsType( FRAME_FOOTPRINT_VIEWER )
         || aFrame->IsType( FRAME_FOOTPRINT_VIEWER_MODAL )
@@ -1042,7 +1044,7 @@ void FOOTPRINT::GetMsgPanelInfo( EDA_DRAW_FRAME* aFrame, std::vector<MSG_PANEL_I
         aList.emplace_back( _( "Pads" ), wxString::Format( wxT( "%zu" ), padCount ) );
 
         aList.emplace_back( wxString::Format( _( "Doc: %s" ), GetDescription() ),
-                               wxString::Format( _( "Keywords: %s" ), GetKeywords() ) );
+                            wxString::Format( _( "Keywords: %s" ), GetKeywords() ) );
 
         return;
     }
@@ -2077,13 +2079,13 @@ double FOOTPRINT::GetCoverageArea( const BOARD_ITEM* aItem, const GENERAL_COLLEC
     {
         const FP_TEXT* text = static_cast<const FP_TEXT*>( aItem );
 
-        text->TransformTextToPolySet( poly, UNDEFINED_LAYER, textMargin, ARC_LOW_DEF, ERROR_OUTSIDE );
+        text->TransformTextToPolySet( poly, textMargin, ARC_LOW_DEF, ERROR_OUTSIDE );
     }
     else if( aItem->Type() == PCB_FP_TEXTBOX_T )
     {
         const FP_TEXTBOX* tb = static_cast<const FP_TEXTBOX*>( aItem );
 
-        tb->TransformTextToPolySet( poly, UNDEFINED_LAYER, textMargin, ARC_LOW_DEF, ERROR_OUTSIDE );
+        tb->TransformTextToPolySet( poly, textMargin, ARC_LOW_DEF, ERROR_OUTSIDE );
     }
     else if( aItem->Type() == PCB_SHAPE_T )
     {
@@ -2879,7 +2881,7 @@ void FOOTPRINT::TransformFPShapesToPolySet( SHAPE_POLY_SET& aBuffer, PCB_LAYER_I
     }
 
     for( const FP_TEXT* text : texts )
-        text->TransformTextToPolySet( aBuffer, aLayer, aClearance, aError, aErrorLoc );
+        text->TransformTextToPolySet( aBuffer, aClearance, aError, aErrorLoc );
 }
 
 
