@@ -493,11 +493,10 @@ void FOOTPRINT_VIEWER_FRAME::ReCreateLibraryList()
         {
             const wxString       term = tokenizer.GetNextToken().Lower();
             EDA_COMBINED_MATCHER matcher( term, CTX_LIBITEM );
-            int                  matches, position;
 
             for( const wxString& nickname : nicknames )
             {
-                if( matcher.Find( nickname.Lower(), matches, position ) )
+                if( matcher.Find( nickname.Lower() ) )
                     process( nickname );
             }
         }
@@ -570,12 +569,11 @@ void FOOTPRINT_VIEWER_FRAME::ReCreateFootprintList()
         {
             const wxString       term = tokenizer.GetNextToken().Lower();
             EDA_COMBINED_MATCHER matcher( term, CTX_LIBITEM );
-            int                  matches, position;
 
             for( const std::unique_ptr<FOOTPRINT_INFO>& footprint : fp_info_list->GetList() )
             {
                 wxString search = footprint->GetFootprintName() + wxS( " " ) + footprint->GetSearchText();
-                bool     matched = matcher.Find( search.Lower(), matches, position );
+                bool     matched = matcher.Find( search.Lower() );
 
                 if( !matched && term.IsNumber() )
                     matched = ( wxAtoi( term ) == (int)footprint->GetPadCount() );
@@ -667,7 +665,8 @@ void FOOTPRINT_VIEWER_FRAME::OnCharHook( wxKeyEvent& aEvent )
         else
             aEvent.Skip();
     }
-    else if( aEvent.GetKeyCode() == WXK_RETURN && m_fpList->GetSelection() >= 0 )
+    else if( ( aEvent.GetKeyCode() == WXK_RETURN || aEvent.GetKeyCode() == WXK_NUMPAD_ENTER )
+             && m_fpList->GetSelection() >= 0 )
     {
         wxCommandEvent dummy;
         AddFootprintToPCB( dummy );
@@ -1239,6 +1238,9 @@ void FOOTPRINT_VIEWER_FRAME::SelectAndViewFootprint( int aMode )
         setCurFootprintName( m_fpList->GetBaseString( selection ) );
 
         // Delete the current footprint
+        if( PCB_SELECTION_TOOL* selectionTool = m_toolManager->GetTool<PCB_SELECTION_TOOL>() )
+            selectionTool->ClearSelection( true /* quiet mode */ );
+
         GetBoard()->DeleteAllFootprints();
         GetBoard()->GetNetInfo().RemoveUnusedNets();
 
