@@ -341,12 +341,24 @@ PCB_EDIT_FRAME::PCB_EDIT_FRAME( KIWAY* aKiway, wxWindow* aParent ) :
                             settings->m_AuiPanels.properties_panel_width, -1 );
         }
 
-        if( settings->m_AuiPanels.search_panel_height > 0 )
+        if( settings->m_AuiPanels.search_panel_height > 0
+            && ( settings->m_AuiPanels.search_panel_dock_direction == wxAUI_DOCK_TOP
+                || settings->m_AuiPanels.search_panel_dock_direction == wxAUI_DOCK_BOTTOM ) )
         {
             wxAuiPaneInfo& searchPane = m_auimgr.GetPane( SearchPaneName() );
+            searchPane.Direction( settings->m_AuiPanels.search_panel_dock_direction );
             SetAuiPaneSize( m_auimgr, searchPane, -1, settings->m_AuiPanels.search_panel_height );
         }
 
+        else if( settings->m_AuiPanels.search_panel_width > 0
+                && ( settings->m_AuiPanels.search_panel_dock_direction == wxAUI_DOCK_LEFT
+                    || settings->m_AuiPanels.search_panel_dock_direction == wxAUI_DOCK_RIGHT ) )
+        {
+            wxAuiPaneInfo& searchPane = m_auimgr.GetPane( SearchPaneName() );
+            searchPane.Direction( settings->m_AuiPanels.search_panel_dock_direction );
+            SetAuiPaneSize( m_auimgr, searchPane, settings->m_AuiPanels.search_panel_width, -1 );
+        }
+
         m_appearancePanel->SetTabIndex( settings->m_AuiPanels.appearance_panel_tab );
     }
 
@@ -971,11 +983,11 @@ void PCB_EDIT_FRAME::RecordDRCExclusions()
 }
 
 
-void PCB_EDIT_FRAME::ResolveDRCExclusions()
+void PCB_EDIT_FRAME::ResolveDRCExclusions( bool aCreateMarkers )
 {
     BOARD_COMMIT commit( this );
 
-    for( PCB_MARKER* marker : GetBoard()->ResolveDRCExclusions() )
+    for( PCB_MARKER* marker : GetBoard()->ResolveDRCExclusions( aCreateMarkers ) )
     {
         if( marker->GetMarkerType() == MARKER_BASE::MARKER_DRAWING_SHEET )
             marker->GetRCItem()->SetItems( GetCanvas()->GetDrawingSheet() );
@@ -1250,9 +1262,12 @@ void PCB_EDIT_FRAME::SaveSettings( APP_SETTINGS_BASE* aCfg )
         }
 
         // ensure m_show_search is up to date (the pane can be closed)
-        m_show_search = m_auimgr.GetPane( SearchPaneName() ).IsShown();
+        wxAuiPaneInfo& searchPaneInfo = m_auimgr.GetPane( SearchPaneName() );
+        m_show_search = searchPaneInfo.IsShown();
         cfg->m_AuiPanels.show_search = m_show_search;
         cfg->m_AuiPanels.search_panel_height = m_searchPane->GetSize().y;
+        cfg->m_AuiPanels.search_panel_width = m_searchPane->GetSize().x;
+        cfg->m_AuiPanels.search_panel_dock_direction = searchPaneInfo.dock_direction;
     }
 }
 
@@ -1642,15 +1657,15 @@ void PCB_EDIT_FRAME::ShowFindDialog()
         switch( front->Type() )
         {
         case PCB_FOOTPRINT_T:
-            findString = static_cast<FOOTPRINT*>( front )->GetValue();
+            findString = UnescapeString( static_cast<FOOTPRINT*>( front )->GetValue() );
             break;
 
         case PCB_FP_TEXT_T:
-            findString = static_cast<FP_TEXT*>( front )->GetShownText();
+            findString = UnescapeString( static_cast<FP_TEXT*>( front )->GetText() );
             break;
 
         case PCB_TEXT_T:
-            findString = static_cast<PCB_TEXT*>( front )->GetShownText();
+            findString = UnescapeString( static_cast<PCB_TEXT*>( front )->GetText() );
 
             if( findString.Contains( wxT( "\n" ) ) )
                 findString = findString.Before( '\n' );
