@@ -52,7 +52,7 @@ PCB_TEXT::~PCB_TEXT()
 }
 
 
-wxString PCB_TEXT::GetShownText( int aDepth, bool aAllowExtraText ) const
+wxString PCB_TEXT::GetShownText( bool aAllowExtraText, int aDepth ) const
 {
     BOARD* board = dynamic_cast<BOARD*>( GetParent() );
 
@@ -73,7 +73,7 @@ wxString PCB_TEXT::GetShownText( int aDepth, bool aAllowExtraText ) const
                 return false;
             };
 
-    wxString text = EDA_TEXT::GetShownText();
+    wxString text = EDA_TEXT::GetShownText( aAllowExtraText, aDepth );
 
     if( board && HasTextVars() && aDepth < 10 )
         text = ExpandTextVars( text, &pcbTextResolver );
@@ -82,6 +82,12 @@ wxString PCB_TEXT::GetShownText( int aDepth, bool aAllowExtraText ) const
 }
 
 
+bool PCB_TEXT::Matches( const EDA_SEARCH_DATA& aSearchData, void* aAuxData ) const
+{
+    return BOARD_ITEM::Matches( UnescapeString( GetText() ), aSearchData );
+}
+
+
 double PCB_TEXT::ViewGetLOD( int aLayer, KIGFX::VIEW* aView ) const
 {
     constexpr double HIDE = std::numeric_limits<double>::max();
@@ -153,18 +159,12 @@ const BOX2I PCB_TEXT::GetBoundingBox() const
 
 bool PCB_TEXT::TextHitTest( const VECTOR2I& aPoint, int aAccuracy ) const
 {
+    int accuracy = aAccuracy;
+
     if( IsKnockout() )
-    {
-        SHAPE_POLY_SET poly;
+        accuracy += GetKnockoutTextMargin( GetTextSize(), GetTextThickness() );
 
-        TransformBoundingBoxToPolygon( &poly, getKnockoutMargin());
-
-        return poly.Collide( aPoint, aAccuracy );
-    }
-    else
-    {
-        return EDA_TEXT::TextHitTest( aPoint, aAccuracy );
-    }
+    return EDA_TEXT::TextHitTest( aPoint, accuracy );
 }
 
 
@@ -237,7 +237,7 @@ void PCB_TEXT::Flip( const VECTOR2I& aCentre, bool aFlipLeftRight )
 wxString PCB_TEXT::GetItemDescription( UNITS_PROVIDER* aUnitsProvider ) const
 {
     return wxString::Format( _( "PCB Text '%s' on %s"),
-                             KIUI::EllipsizeMenuText( GetShownText() ),
+                             KIUI::EllipsizeMenuText( GetShownText( false ) ),
                              GetLayerName() );
 }
 
@@ -266,29 +266,48 @@ std::shared_ptr<SHAPE> PCB_TEXT::GetEffectiveShape( PCB_LAYER_ID aLayer, FLASHIN
 {
     if( IsKnockout() )
     {
-        SHAPE_POLY_SET knockouts;
+        SHAPE_POLY_SET poly;
 
-        TransformTextToPolySet( knockouts, aLayer, 0, GetBoard()->GetDesignSettings().m_MaxError,
-                                ERROR_INSIDE );
+        TransformTextToPolySet( poly, 0, GetBoard()->GetDesignSettings().m_MaxError, ERROR_INSIDE );
 
-        SHAPE_POLY_SET finalPoly;
-        int            strokeWidth = GetEffectiveTextPenWidth();
-        VECTOR2I       fontSize = GetTextSize();
-        int            margin = strokeWidth * 1.5 + GetKnockoutTextMargin( fontSize, strokeWidth );
-
-        TransformBoundingBoxToPolygon( &finalPoly, margin );
-        finalPoly.BooleanSubtract( knockouts, SHAPE_POLY_SET::PM_FAST );
-        finalPoly.Fracture( SHAPE_POLY_SET::PM_FAST );
-
-        return std::make_shared<SHAPE_POLY_SET>( finalPoly );
+        return std::make_shared<SHAPE_POLY_SET>( poly );
     }
 
     return GetEffectiveTextShape();
 }
 
 
-void PCB_TEXT::TransformTextToPolySet( SHAPE_POLY_SET& aBuffer, PCB_LAYER_ID aLayer,
-                                       int aClearance, int aError, ERROR_LOC aErrorLoc ) const
+void PCB_TEXT::buildBoundingHull( SHAPE_POLY_SET* aBuffer, const SHAPE_POLY_SET& aRenderedText,
+                                  int aClearance ) const
+{
+    SHAPE_POLY_SET poly( aRenderedText );
+
+    poly.Rotate( -GetDrawRotation(), GetDrawPos() );
+
+    BOX2I    rect = poly.BBox( aClearance );
+    VECTOR2I corners[4];
+
+    corners[0].x = rect.GetOrigin().x;
+    corners[0].y = rect.GetOrigin().y;
+    corners[1].y = corners[0].y;
+    corners[1].x = rect.GetRight();
+    corners[2].x = corners[1].x;
+    corners[2].y = rect.GetBottom();
+    corners[3].y = corners[2].y;
+    corners[3].x = corners[0].x;
+
+    aBuffer->NewOutline();
+
+    for( VECTOR2I& corner : corners )
+    {
+        RotatePoint( corner, GetDrawPos(), GetDrawRotation() );
+        aBuffer->Append( corner.x, corner.y );
+    }
+}
+
+
+void PCB_TEXT::TransformTextToPolySet( SHAPE_POLY_SET& aBuffer, int aClearance, int aError,
+                                       ERROR_LOC aErrorLoc ) const
 {
     KIGFX::GAL_DISPLAY_OPTIONS empty_opts;
     KIFONT::FONT*              font = getDrawFont();
@@ -297,43 +316,45 @@ void PCB_TEXT::TransformTextToPolySet( SHAPE_POLY_SET& aBuffer, PCB_LAYER_ID aLa
     // The polygonal shape of a text can have many basic shapes, so combining these shapes can
     // be very useful to create a final shape with a lot less vertices to speedup calculations.
     // Simplify shapes is not usually always efficient, but in this case it is.
-    SHAPE_POLY_SET buffer;
+    SHAPE_POLY_SET textShape;
 
     CALLBACK_GAL callback_gal( empty_opts,
             // Stroke callback
             [&]( const VECTOR2I& aPt1, const VECTOR2I& aPt2 )
             {
-                TransformOvalToPolygon( buffer, aPt1, aPt2, penWidth + ( 2 * aClearance ),
-                                        aError, ERROR_INSIDE );
+                TransformOvalToPolygon( textShape, aPt1, aPt2, penWidth, aError, aErrorLoc );
             },
             // Triangulation callback
             [&]( const VECTOR2I& aPt1, const VECTOR2I& aPt2, const VECTOR2I& aPt3 )
             {
-                buffer.NewOutline();
+                textShape.NewOutline();
 
                 for( const VECTOR2I& point : { aPt1, aPt2, aPt3 } )
-                    buffer.Append( point.x, point.y );
+                    textShape.Append( point.x, point.y );
             } );
 
-    font->Draw( &callback_gal, GetShownText(), GetTextPos(), GetAttributes() );
+    TEXT_ATTRIBUTES attrs = GetAttributes();
+    attrs.m_Angle = GetDrawRotation();
 
-    buffer.Simplify( SHAPE_POLY_SET::PM_FAST );
+    font->Draw( &callback_gal, GetShownText( true ), GetTextPos(), attrs );
+    textShape.Simplify( SHAPE_POLY_SET::PM_FAST );
 
     if( IsKnockout() )
     {
-        TEXT_ATTRIBUTES attrs = GetAttributes();
         SHAPE_POLY_SET finalPoly;
-        int            margin = attrs.m_StrokeWidth * 1.5
-                                    + GetKnockoutTextMargin( attrs.m_Size, attrs.m_StrokeWidth );
+        int            margin = GetKnockoutTextMargin( attrs.m_Size, penWidth );
 
-        TransformBoundingBoxToPolygon( &finalPoly, margin );
-        finalPoly.BooleanSubtract( buffer, SHAPE_POLY_SET::PM_FAST );
+        buildBoundingHull( &finalPoly, textShape, margin + aClearance );
+        finalPoly.BooleanSubtract( textShape, SHAPE_POLY_SET::PM_FAST );
 
         aBuffer.Append( finalPoly );
     }
     else
     {
-        aBuffer.Append( buffer );
+        if( aClearance > 0 )
+            textShape.Inflate( aClearance, aClearance );
+
+        aBuffer.Append( textShape );
     }
 }
 
@@ -342,7 +363,11 @@ void PCB_TEXT::TransformShapeToPolygon( SHAPE_POLY_SET& aBuffer, PCB_LAYER_ID aL
                                         int aClearance, int aError, ERROR_LOC aErrorLoc,
                                         bool aIgnoreLineWidth ) const
 {
-    EDA_TEXT::TransformBoundingBoxToPolygon( &aBuffer, aClearance );
+    SHAPE_POLY_SET poly;
+
+    TransformTextToPolySet( poly, 0, GetBoard()->GetDesignSettings().m_MaxError, aErrorLoc );
+
+    buildBoundingHull( &aBuffer, poly, aClearance );
 }
 
 
