@@ -57,6 +57,8 @@
 #include <zone.h>
 #include <zones.h>
 
+#include <kiplatform/io.h>
+
 // For some reason wxWidgets is built with wxUSE_BASE64 unset so expose the wxWidgets
 // base64 code. Needed for PCB_BITMAP
 #define wxUSE_BASE64 1
@@ -131,6 +133,9 @@ void FP_CACHE::Save( FOOTPRINT* aFootprint )
         // and it is fully inexplicable.  See if this dodges the error.
         wxMilliSleep( 250L );
 
+        // Preserve the permissions of the current file
+        KIPLATFORM::IO::DuplicatePermissions( fn.GetFullPath(), tempFileName );
+
         if( !wxRenameFile( tempFileName, fn.GetFullPath() ) )
         {
             wxString msg = wxString::Format( _( "Cannot rename temporary file '%s' to '%s'" ),
@@ -277,7 +282,7 @@ void PCB_PLUGIN::Save( const wxString& aFileName, BOARD* aBoard, const STRING_UT
 
     if( sanityResult != wxEmptyString && m_queryUserCallback )
     {
-        if( !(*m_queryUserCallback)(
+        if( !m_queryUserCallback(
                     _( "Internal Group Data Error" ), wxICON_ERROR,
                     wxString::Format( _( "Please report this bug.  Error validating group "
                                          "structure: %s\n\nSave anyway?" ), sanityResult ),
@@ -476,16 +481,45 @@ void PCB_PLUGIN::formatPolyPts( const SHAPE_LINE_CHAIN& outline, int aNestLevel,
 
 void PCB_PLUGIN::formatRenderCache( const EDA_TEXT* aText, int aNestLevel ) const
 {
-    const wxString& shownText = aText->GetShownText();
+    wxString resolvedText( aText->GetShownText( true ) );
     std::vector<std::unique_ptr<KIFONT::GLYPH>>* cache = aText->GetRenderCache( aText->GetFont(),
-                                                                                shownText );
+                                                                                resolvedText );
 
     m_out->Print( aNestLevel, "(render_cache %s %s\n",
-                  m_out->Quotew( shownText ).c_str(),
+                  m_out->Quotew( resolvedText ).c_str(),
                   EDA_UNIT_UTILS::FormatAngle( aText->GetDrawRotation() ).c_str() );
 
     for( const std::unique_ptr<KIFONT::GLYPH>& baseGlyph : *cache )
     {
+        // A glyph is not aways a polygon. it can be a stroke (for instance a text with overbar)
+        // we save only polygons from cache
+        // So convert any stroke to a polygon
+        if( baseGlyph->IsStroke() )
+        {
+            const KIFONT::STROKE_GLYPH& strokeGlyph = static_cast<const KIFONT::STROKE_GLYPH&>( *baseGlyph );
+
+            for( const std::vector<VECTOR2D>& points : strokeGlyph )
+            {
+                SHAPE_LINE_CHAIN outline;
+
+                for( size_t idx = 0; idx < points.size(); idx++ )
+                    outline.Append( (int)points[idx].x, (int)points[idx].y );
+
+                for( int idx = 1; idx < outline.PointCount(); idx++ )
+                {
+                    SHAPE_POLY_SET buffer;
+                    TransformOvalToPolygon( buffer, outline.CPoint( idx-1 ), outline.CPoint( idx ),
+                                            aText->GetTextThickness(), ARC_LOW_DEF, ERROR_INSIDE );
+
+                    m_out->Print( aNestLevel + 1, "(polygon\n" );
+                    formatPolyPts( buffer.Outline(0), aNestLevel + 2, true );
+                    m_out->Print( aNestLevel + 1, ")\n" );
+                }
+            }
+
+            continue;
+        }
+
         KIFONT::OUTLINE_GLYPH* glyph = static_cast<KIFONT::OUTLINE_GLYPH*>( baseGlyph.get() );
 
         if( glyph->OutlineCount() > 0 )
@@ -818,7 +852,7 @@ void PCB_PLUGIN::format( const PCB_DIMENSION_BASE* aDimension, int aNestLevel )
                       m_out->Quotew( aDimension->GetSuffix() ).c_str(),
                       static_cast<int>( aDimension->GetUnitsMode() ),
                       static_cast<int>( aDimension->GetUnitsFormat() ),
-                      aDimension->GetPrecision() );
+                      static_cast<int>( aDimension->GetPrecision() ) );
 
         if( aDimension->GetOverrideTextEnabled() )
         {
@@ -2349,8 +2383,7 @@ void PCB_PLUGIN::format( const ZONE* aZone, int aNestLevel ) const
 PCB_PLUGIN::PCB_PLUGIN( int aControlFlags ) :
     m_cache( nullptr ),
     m_ctl( aControlFlags ),
-    m_mapping( new NETINFO_MAPPING() ),
-    m_queryUserCallback( nullptr )
+    m_mapping( new NETINFO_MAPPING() )
 {
     init( nullptr );
     m_out = &m_sf;
