@@ -90,19 +90,15 @@ VVIA* DRAGGER::checkVirtualVia( const VECTOR2D& aP, SEGMENT* aSeg )
         return nullptr;
     }
 
-    JOINT *jt = m_world->FindJoint( psnap, aSeg );
+    const JOINT *jt = m_world->FindJoint( psnap, aSeg );
 
     if ( !jt )
-    {
         return nullptr;
-    }
 
-    for( auto& lnk : jt->LinkList() )
+    for( ITEM* item : jt->LinkList() )
     {
-        if( lnk.item->IsVirtual() && lnk.item->OfKind( ITEM::VIA_T ))
-        {
-            return static_cast<VVIA*>( lnk.item );
-        }
+        if( item->IsVirtual() && item->OfKind( ITEM::VIA_T ))
+            return static_cast<VVIA*>( item );
     }
 
     return nullptr;
@@ -175,7 +171,7 @@ const ITEM_SET DRAGGER::findViaFanoutByHandle ( NODE *aNode, const VIA_HANDLE& h
 {
     ITEM_SET rv;
 
-    JOINT* jt = aNode->FindJoint( handle.pos, handle.layers.Start(), handle.net );
+    const JOINT* jt = aNode->FindJoint( handle.pos, handle.layers.Start(), handle.net );
 
     if( !jt )
         return rv;
@@ -327,7 +323,7 @@ bool DRAGGER::dragMarkObstacles( const VECTOR2I& aP )
     if( Settings().AllowDRCViolations() )
         m_dragStatus = true;
     else
-        m_dragStatus = !m_world->CheckColliding( m_draggedItems );
+        m_dragStatus = !m_lastNode->CheckColliding( m_draggedItems );
 
     return true;
 }
@@ -402,13 +398,14 @@ bool DRAGGER::dragViaWalkaround( const VIA_HANDLE& aHandle, NODE* aNode, const V
 
             vias.insert( draggedVia.get() );
 
+            m_lastNode->Remove( via );
+
             bool ok = propagateViaForces( m_lastNode, vias );
 
             if( ok )
             {
                 viaTargetPos = draggedVia->Pos();
                 viaPropOk = true;
-                m_lastNode->Remove( via );
                 m_lastNode->Add( std::move(draggedVia) );
             }
         }
@@ -608,7 +605,7 @@ bool DRAGGER::dragWalkaround( const VECTOR2I& aP )
 
     m_dragStatus = ok;
 
-    return true;
+    return ok;
 }
 
 
@@ -749,7 +746,18 @@ bool DRAGGER::Drag( const VECTOR2I& aP )
     }
 
     if( ret )
+    {
         m_lastValidPoint = aP;
+    }
+    else
+    {
+        if( m_lastNode )
+        {
+            delete m_lastNode;
+            m_draggedItems.Clear();
+            m_lastNode = nullptr;
+        }
+    }
 
     return ret;
 }
