@@ -106,33 +106,28 @@ public:
 
     virtual int Clearance( const PNS::ITEM* aA, const PNS::ITEM* aB,
                            bool aUseClearanceEpsilon = true ) override;
-    virtual int HoleClearance( const PNS::ITEM* aA, const PNS::ITEM* aB,
-                               bool aUseClearanceEpsilon = true ) override;
-    virtual int HoleToHoleClearance( const PNS::ITEM* aA, const PNS::ITEM* aB,
-                                     bool aUseClearanceEpsilon = true ) override;
 
     virtual int DpCoupledNet( int aNet ) override;
     virtual int DpNetPolarity( int aNet ) override;
     virtual bool DpNetPair( const PNS::ITEM* aItem, int& aNetP, int& aNetN ) override;
-    virtual bool IsDiffPair( const PNS::ITEM* aA, const PNS::ITEM* aB ) override;
 
     virtual bool IsInNetTie( const PNS::ITEM* aA ) override;
     virtual bool IsNetTieExclusion( const PNS::ITEM* aItem, const VECTOR2I& aCollisionPos,
                                     const PNS::ITEM* aCollidingItem ) override;
 
+    virtual bool IsKeepout( const PNS::ITEM* aA, const PNS::ITEM* aB ) override;
+
     virtual bool QueryConstraint( PNS::CONSTRAINT_TYPE aType, const PNS::ITEM* aItemA,
                                   const PNS::ITEM* aItemB, int aLayer,
                                   PNS::CONSTRAINT* aConstraint ) override;
     virtual wxString NetName( int aNet ) override;
 
-    int ClearanceEpsilon() const { return m_clearanceEpsilon; }
+    int ClearanceEpsilon() const override { return m_clearanceEpsilon; }
 
-    void ClearCacheForItem( const PNS::ITEM* aItem ) override;
+    void ClearCacheForItems( std::vector<const PNS::ITEM*>& aItems ) override;
     void ClearCaches() override;
 
 private:
-    int holeRadius( const PNS::ITEM* aItem ) const;
-
     /**
      * Checks for netnamed differential pairs.
      * This accepts nets named suffixed by 'P', 'N', '+', '-', as well as additional
@@ -153,8 +148,6 @@ private:
     int                m_clearanceEpsilon;
 
     std::unordered_map<CLEARANCE_CACHE_KEY, int> m_clearanceCache;
-    std::unordered_map<CLEARANCE_CACHE_KEY, int> m_holeClearanceCache;
-    std::unordered_map<CLEARANCE_CACHE_KEY, int> m_holeToHoleClearanceCache;
 };
 
 
@@ -178,47 +171,10 @@ PNS_PCBNEW_RULE_RESOLVER::~PNS_PCBNEW_RULE_RESOLVER()
 }
 
 
-int PNS_PCBNEW_RULE_RESOLVER::holeRadius( const PNS::ITEM* aItem ) const
-{
-    if( aItem->Kind() == PNS::ITEM::SOLID_T )
-    {
-        const PAD* pad = dynamic_cast<const PAD*>( aItem->Parent() );
-
-        if( pad && pad->GetDrillShape() == PAD_DRILL_SHAPE_CIRCLE )
-            return pad->GetDrillSize().x / 2;
-    }
-    else if( aItem->Kind() == PNS::ITEM::VIA_T )
-    {
-        const PCB_VIA* via = dynamic_cast<const PCB_VIA*>( aItem->Parent() );
-
-        if( via )
-            return via->GetDrillValue() / 2;
-    }
-
-    return 0;
-}
-
-
-bool PNS_PCBNEW_RULE_RESOLVER::IsDiffPair( const PNS::ITEM* aA, const PNS::ITEM* aB )
-{
-    int net_p, net_n;
-
-    if( !DpNetPair( aA, net_p, net_n ) )
-        return false;
-
-    if( aA->Net() == net_p && aB->Net() == net_n )
-        return true;
-
-    if( aB->Net() == net_p && aA->Net() == net_n )
-        return true;
-
-    return false;
-}
-
-
 bool PNS_PCBNEW_RULE_RESOLVER::IsInNetTie( const PNS::ITEM* aA )
 {
-    BOARD_ITEM* item = aA->Parent();
+    BOARD_ITEM* item = aA->BoardItem();
+
     BOARD_ITEM* parentFootprint = item ? item->GetParentFootprint() : nullptr;
 
     if( parentFootprint )
@@ -235,7 +191,8 @@ bool PNS_PCBNEW_RULE_RESOLVER::IsNetTieExclusion( const PNS::ITEM* aItem,
     wxCHECK( aItem && aCollidingItem, false );
 
     std::shared_ptr<DRC_ENGINE> drcEngine = m_board->GetDesignSettings().m_DRCEngine;
-    BOARD_ITEM*                 collidingItem = aCollidingItem->Parent();
+    BOARD_ITEM*                 item = aItem->BoardItem();
+    BOARD_ITEM*                 collidingItem = aCollidingItem->BoardItem();
 
     FOOTPRINT* collidingFp = static_cast<FOOTPRINT*>( collidingItem->GetParentFootprint() );
     FOOTPRINT* itemFp      = aItem->Parent()
@@ -258,17 +215,100 @@ bool PNS_PCBNEW_RULE_RESOLVER::IsNetTieExclusion( const PNS::ITEM* aItem,
 }
 
 
-bool isCopper( const PNS::ITEM* aItem )
+bool PNS_PCBNEW_RULE_RESOLVER::IsKeepout( const PNS::ITEM* aA, const PNS::ITEM* aB )
 {
+    auto checkKeepout =
+            []( const ZONE* aKeepout, const BOARD_ITEM* aOther )
+            {
+                if( aKeepout->GetDoNotAllowTracks() && aOther->IsType( { PCB_ARC_T, PCB_TRACE_T } ) )
+                    return true;
+
+                if( aKeepout->GetDoNotAllowVias() && aOther->Type() == PCB_VIA_T )
+                    return true;
+
+                if( aKeepout->GetDoNotAllowPads() && aOther->Type() == PCB_PAD_T )
+                    return true;
+
+                // Incomplete test, but better than nothing:
+                if( aKeepout->GetDoNotAllowFootprints() && aOther->Type() == PCB_PAD_T )
+                {
+                    return !aKeepout->GetParentFootprint()
+                            || aKeepout->GetParentFootprint() != aOther->GetParentFootprint();
+                }
+
+                return false;
+            };
+
+    if( const ZONE* zoneA = dynamic_cast<ZONE*>( aA->Parent() ) )
+    {
+        if( zoneA->GetIsRuleArea() && aB->Parent() )
+            return checkKeepout( zoneA, aB->Parent() );
+    }
+
+    if( const ZONE* zoneB = dynamic_cast<ZONE*>( aB->Parent() ) )
+    {
+        if( zoneB->GetIsRuleArea() && aA->Parent() )
+            return checkKeepout( zoneB, aA->Parent() );
+    }
+
+    return false;
+}
+
+
+static bool isCopper( const PNS::ITEM* aItem )
+{
+    if ( !aItem )
+        return false;
+
     const BOARD_ITEM *parent = aItem->Parent();
 
     return !parent || parent->IsOnCopperLayer();
 }
 
 
-bool isEdge( const PNS::ITEM* aItem )
+static bool isHole( const PNS::ITEM* aItem )
 {
-    const BOARD_ITEM *parent = aItem->Parent();
+    if ( !aItem )
+        return false;
+
+    return aItem->OfKind( PNS::ITEM::HOLE_T );
+}
+
+
+static bool isDrilledHole( const PNS::ITEM* aItem )
+{
+    if( !isHole( aItem ) )
+        return false;
+
+    if( PAD* pad = dynamic_cast<PAD*>( aItem->Parent() ) )
+        return pad->GetDrillSizeX() && pad->GetDrillSizeX() == pad->GetDrillSizeY();
+
+    // Via holes are (currently) always round
+
+    return true;
+}
+
+
+static bool isNonPlatedSlot( const PNS::ITEM* aItem )
+{
+    if( !isHole( aItem ) )
+        return false;
+
+    if( PAD* pad = dynamic_cast<PAD*>( aItem->Parent() ) )
+        return pad->GetAttribute() == PAD_ATTRIB::NPTH && pad->GetDrillSizeX() != pad->GetDrillSizeY();
+
+    // Via holes are (currently) always round
+
+    return false;
+}
+
+
+static bool isEdge( const PNS::ITEM* aItem )
+{
+    if ( !aItem )
+        return false;
+
+    const BOARD_ITEM *parent = aItem->BoardItem();
 
     return parent && ( parent->IsOnLayer( Edge_Cuts ) || parent->IsOnLayer( Margin ) );
 }
@@ -299,8 +339,8 @@ bool PNS_PCBNEW_RULE_RESOLVER::QueryConstraint( PNS::CONSTRAINT_TYPE aType,
     default:                                      return false; // should not happen
     }
 
-    BOARD_ITEM*    parentA = aItemA ? aItemA->Parent() : nullptr;
-    BOARD_ITEM*    parentB = aItemB ? aItemB->Parent() : nullptr;
+    BOARD_ITEM*    parentA = aItemA ? aItemA->BoardItem() : nullptr;
+    BOARD_ITEM*    parentB = aItemB ? aItemB->BoardItem() : nullptr;
     DRC_CONSTRAINT hostConstraint;
 
     // A track being routed may not have a BOARD_ITEM associated yet.
@@ -312,6 +352,7 @@ bool PNS_PCBNEW_RULE_RESOLVER::QueryConstraint( PNS::CONSTRAINT_TYPE aType,
         case PNS::ITEM::VIA_T:     parentA = &m_dummyVias[0];   break;
         case PNS::ITEM::SEGMENT_T: parentA = &m_dummyTracks[0]; break;
         case PNS::ITEM::LINE_T:    parentA = &m_dummyTracks[0]; break;
+        case PNS::ITEM::HOLE_T:    parentA = &m_dummyVias[0];   break;
         default: break;
         }
 
@@ -330,6 +371,7 @@ bool PNS_PCBNEW_RULE_RESOLVER::QueryConstraint( PNS::CONSTRAINT_TYPE aType,
         case PNS::ITEM::VIA_T:     parentB = &m_dummyVias[1];   break;
         case PNS::ITEM::SEGMENT_T: parentB = &m_dummyTracks[1]; break;
         case PNS::ITEM::LINE_T:    parentB = &m_dummyTracks[1]; break;
+        case PNS::ITEM::HOLE_T:    parentB = &m_dummyVias[1];   break;
         default: break;
         }
 
@@ -375,21 +417,36 @@ bool PNS_PCBNEW_RULE_RESOLVER::QueryConstraint( PNS::CONSTRAINT_TYPE aType,
 }
 
 
-void PNS_PCBNEW_RULE_RESOLVER::ClearCacheForItem( const PNS::ITEM* aItem )
+void PNS_PCBNEW_RULE_RESOLVER::ClearCacheForItems( std::vector<const PNS::ITEM*>& aItems )
 {
-    CLEARANCE_CACHE_KEY key = { aItem, nullptr, false };
-    m_clearanceCache.erase( key );
+    int n_pruned = 0;
+    std::set<const PNS::ITEM*> remainingItems( aItems.begin(), aItems.end() );
 
-    key.Flag = true;
-    m_clearanceCache.erase( key );
+/* We need to carefully check both A and B item pointers in the cache against dirty/invalidated
+   items in the set, as the clearance relation is commutative ( CL[a,b] == CL[b,a] ). The code
+   below is a bit ugly, but works in O(n*log(m)) and is run once or twice during ROUTER::Move() call
+   - so I hope it still gets better performance than no cache at all */
+    for( auto it = m_clearanceCache.begin(); it != m_clearanceCache.end(); )
+    {
+        bool dirty = remainingItems.find( it->first.A ) != remainingItems.end();
+        dirty |= remainingItems.find( it->first.B) != remainingItems.end();
+
+        if( dirty )
+        {
+            it = m_clearanceCache.erase( it );
+            n_pruned++;
+        } else
+            it++;
+    }
+#if 0
+    printf("ClearCache : n_pruned %d\n", n_pruned );
+#endif
 }
 
 
 void PNS_PCBNEW_RULE_RESOLVER::ClearCaches()
 {
     m_clearanceCache.clear();
-    m_holeClearanceCache.clear();
-    m_holeToHoleClearanceCache.clear();
 }
 
 
@@ -420,7 +477,23 @@ int PNS_PCBNEW_RULE_RESOLVER::Clearance( const PNS::ITEM* aA, const PNS::ITEM* a
 
     for( int layer = layers.Start(); layer <= layers.End(); ++layer )
     {
-        if( isCopper( aA ) && ( !aB || isCopper( aB ) ) )
+        if( isDrilledHole( aA ) && isDrilledHole( aB) )
+        {
+            if( QueryConstraint( PNS::CONSTRAINT_TYPE::CT_HOLE_TO_HOLE, aA, aB, layer, &constraint ) )
+            {
+                if( constraint.m_Value.Min() > rv )
+                    rv = constraint.m_Value.Min();
+            }
+        }
+        else if( isHole( aA ) || isHole( aB ) )
+        {
+            if( QueryConstraint( PNS::CONSTRAINT_TYPE::CT_HOLE_CLEARANCE, aA, aB, layer, &constraint ) )
+            {
+                if( constraint.m_Value.Min() > rv )
+                    rv = constraint.m_Value.Min();
+            }
+        }
+        else if( isCopper( aA ) && ( !aB || isCopper( aB ) ) )
         {
             if( QueryConstraint( PNS::CONSTRAINT_TYPE::CT_CLEARANCE, aA, aB, layer, &constraint ) )
             {
@@ -429,7 +502,8 @@ int PNS_PCBNEW_RULE_RESOLVER::Clearance( const PNS::ITEM* aA, const PNS::ITEM* a
             }
         }
 
-        if( isEdge( aA ) || ( aB && isEdge( aB ) ) )
+        // No 'else'; non-plated milled holes get both HOLE_CLEARANCE and EDGE_CLEARANCE
+        if( isEdge( aA ) || isNonPlatedSlot( aA ) || isEdge( aB ) || isNonPlatedSlot( aB ) )
         {
             if( QueryConstraint( PNS::CONSTRAINT_TYPE::CT_EDGE_CLEARANCE, aA, aB, layer, &constraint ) )
             {
@@ -442,75 +516,15 @@ int PNS_PCBNEW_RULE_RESOLVER::Clearance( const PNS::ITEM* aA, const PNS::ITEM* a
     if( aUseClearanceEpsilon && rv > 0 )
         rv = std::max( 0, rv - m_clearanceEpsilon );
 
-    m_clearanceCache[ key ] = rv;
-    return rv;
-}
 
-
-int PNS_PCBNEW_RULE_RESOLVER::HoleClearance( const PNS::ITEM* aA, const PNS::ITEM* aB,
-                                             bool aUseClearanceEpsilon )
-{
-    CLEARANCE_CACHE_KEY key = { aA, aB, aUseClearanceEpsilon };
-    auto it = m_holeClearanceCache.find( key );
-
-    if( it != m_holeClearanceCache.end() )
-        return it->second;
-
-    PNS::CONSTRAINT constraint;
-    int rv = 0;
-    int layer;
-
-    if( !aA->Layers().IsMultilayer() || !aB || aB->Layers().IsMultilayer() )
-        layer = aA->Layer();
-    else
-        layer = aB->Layer();
-
-    if( QueryConstraint( PNS::CONSTRAINT_TYPE::CT_HOLE_CLEARANCE, aA, aB, layer, &constraint ) )
-        rv = constraint.m_Value.Min();
-
-#define HAS_PLATED_HOLE( a ) ( a )->IsRoutable()
-
-    if( IsCopperLayer( layer )
-            && ( HAS_PLATED_HOLE( aA ) || HAS_PLATED_HOLE( aB ) )
-            && QueryConstraint( PNS::CONSTRAINT_TYPE::CT_CLEARANCE, aA, aB, layer, &constraint )
-            && constraint.m_Value.Min() > rv )
+/* It makes no sense to put items that have no owning NODE in the cache - they can be allocated on stack
+   and we can't really invalidate them in the cache when they are destroyed. Probably a better idea would be
+   to use a static unique counter in PNS::ITEM constructor to generate the cache keys. */
+    if( aA && aB && aA->Owner() && aB->Owner() )
     {
-        rv = constraint.m_Value.Min();
+        m_clearanceCache[ key ] = rv;
     }
 
-    if( aUseClearanceEpsilon && rv > 0 )
-        rv = std::max( 0, rv - m_clearanceEpsilon );
-
-    m_holeClearanceCache[ key ] = rv;
-    return rv;
-}
-
-
-int PNS_PCBNEW_RULE_RESOLVER::HoleToHoleClearance( const PNS::ITEM* aA, const PNS::ITEM* aB,
-                                                   bool aUseClearanceEpsilon )
-{
-    CLEARANCE_CACHE_KEY key = { aA, aB, aUseClearanceEpsilon };
-    auto it = m_holeToHoleClearanceCache.find( key );
-
-    if( it != m_holeToHoleClearanceCache.end() )
-        return it->second;
-
-    PNS::CONSTRAINT constraint;
-    int rv = 0;
-    int layer;
-
-    if( !aA->Layers().IsMultilayer() || !aB || aB->Layers().IsMultilayer() )
-        layer = aA->Layer();
-    else
-        layer = aB->Layer();
-
-    if( QueryConstraint( PNS::CONSTRAINT_TYPE::CT_HOLE_TO_HOLE, aA, aB, layer, &constraint ) )
-        rv = constraint.m_Value.Min();
-
-    if( aUseClearanceEpsilon && rv > 0 )
-        rv = std::max( 0, rv - m_clearanceEpsilon );
-
-    m_holeToHoleClearanceCache[ key ] = rv;
     return rv;
 }
 
@@ -554,13 +568,13 @@ bool PNS_KICAD_IFACE_BASE::inheritTrackWidth( PNS::ITEM* aItem, int* aInheritedW
         return false;
     }
 
-    PNS::JOINT* jt = static_cast<PNS::NODE*>( aItem->Owner() )->FindJoint( p, aItem );
+    const PNS::JOINT* jt = static_cast<const PNS::NODE*>( aItem->Owner() )->FindJoint( p, aItem );
 
     assert( jt != nullptr );
 
     int mval = INT_MAX;
 
-    PNS::ITEM_SET linkedSegs = jt->Links();
+    PNS::ITEM_SET linkedSegs( jt->CLinks() );
     linkedSegs.ExcludeItem( aItem ).FilterKinds( PNS::ITEM::SEGMENT_T | PNS::ITEM::ARC_T );
 
     for( PNS::ITEM* item : linkedSegs.Items() )
@@ -1139,7 +1153,7 @@ std::unique_ptr<PNS::SOLID> PNS_KICAD_IFACE_BASE::syncPad( PAD* aPad )
     solid->SetOffset( VECTOR2I( offset.x, offset.y ) );
 
     if( aPad->GetDrillSize().x > 0 )
-        solid->SetHole( aPad->GetEffectiveHoleShape()->Clone() );
+        solid->SetHole( new PNS::HOLE( aPad->GetEffectiveHoleShape()->Clone() ) );
 
     // We generate a single SOLID for a pad, so we have to treat it as ALWAYS_FLASHED and then
     // perform layer-specific flashing tests internally.
@@ -1212,10 +1226,7 @@ std::unique_ptr<PNS::VIA> PNS_KICAD_IFACE_BASE::syncVia( PCB_VIA* aVia )
         via->Mark( PNS::MK_LOCKED );
 
     via->SetIsFree( aVia->GetIsFree() );
-
-    BOARD_DESIGN_SETTINGS& bds = m_board->GetDesignSettings();
-    via->SetHole( SHAPE_CIRCLE( aVia->GetPosition(),
-                                aVia->GetDrillValue() / 2 ) );
+    via->SetHole( PNS::HOLE::MakeCircularHole( aVia->GetPosition(), aVia->GetDrillValue() / 2 ) );
 
     return via;
 }
@@ -1295,59 +1306,40 @@ bool PNS_KICAD_IFACE_BASE::syncTextItem( PNS::NODE* aWorld, EDA_TEXT* aText, PCB
     if( !IsCopperLayer( aLayer ) )
         return false;
 
+    BOARD_ITEM*  boardItem = dynamic_cast<BOARD_ITEM*>( aText );
+    PCB_LAYER_ID layer = boardItem->GetLayer();
+    int          maxError = m_board->GetDesignSettings().m_MaxError;
+
     std::unique_ptr<PNS::SOLID> solid = std::make_unique<PNS::SOLID>();
+    SHAPE_SIMPLE*               shape = new SHAPE_SIMPLE;
 
     solid->SetLayer( aLayer );
     solid->SetNet( -1 );
-    solid->SetParent( dynamic_cast<BOARD_ITEM*>( aText ) );
+    solid->SetShape( shape );   // takes ownership
+    solid->SetParent( boardItem );
 
-    PCB_TEXT* pcb_text = dynamic_cast<PCB_TEXT*>( aText );
+    SHAPE_POLY_SET cornerBuffer;
 
-    if( pcb_text && pcb_text->IsKnockout() )
+    if( boardItem->Type() == PCB_FP_TEXT_T )
     {
-        TEXT_ATTRIBUTES attrs = pcb_text->GetAttributes();
-        SHAPE_POLY_SET buffer;
-        int margin = attrs.m_StrokeWidth * 1.5
-                     + GetKnockoutTextMargin( attrs.m_Size, attrs.m_StrokeWidth );
-        pcb_text->TransformBoundingBoxToPolygon( &buffer, margin );
-        // buffer should contain a single rectangular polygon
-        SHAPE_SIMPLE* rectShape = new SHAPE_SIMPLE;
-
-        for( int ii = 0; ii < buffer.Outline(0).PointCount(); ii++ )
-        {
-            VECTOR2I point = buffer.Outline(0).CPoint(ii);
-            rectShape->Append( point );
-        }
-
-        solid->SetShape( rectShape );
+        static_cast<FP_TEXT*>( boardItem )->TransformShapeToPolygon( cornerBuffer, layer, 0,
+                                                                     maxError, ERROR_OUTSIDE, false );
+    }
+    else if( boardItem->Type() == PCB_TEXT_T )
+    {
+        static_cast<PCB_TEXT*>( boardItem )->TransformShapeToPolygon( cornerBuffer, layer, 0,
+                                                                      maxError, ERROR_OUTSIDE );
     }
-    else
-    solid->SetShape( aText->GetEffectiveTextShape()->Clone() );
 
-    solid->SetRoutable( false );
+    if( !cornerBuffer.OutlineCount() )
+        return false;
+
+    for( const VECTOR2I& pt : cornerBuffer.Outline( 0 ).CPoints() )
+        shape->Append( pt );
 
     aWorld->Add( std::move( solid ) );
 
     return true;
-
-    /* A coarser (but faster) method:
-    SHAPE_POLY_SET outline;
-    SHAPE_SIMPLE* shape = new SHAPE_SIMPLE();
-
-    aText->TransformBoundingBoxToPolygon( &outline, 0 );
-
-    for( auto iter = outline.CIterate( 0 ); iter; iter++ )
-        shape->Append( *iter );
-
-    solid->SetShape( shape );
-
-    solid->SetLayer( aLayer );
-    solid->SetNet( -1 );
-    solid->SetParent( nullptr );
-    solid->SetRoutable( false );
-    aWorld->Add( std::move( solid ) );
-    return true;
-     */
 }
 
 
@@ -1453,6 +1445,50 @@ bool PNS_KICAD_IFACE_BASE::IsFlashedOnLayer( const PNS::ITEM* aItem, int aLayer
 }
 
 
+bool PNS_KICAD_IFACE_BASE::IsFlashedOnLayer( const PNS::ITEM* aItem,
+                                             const LAYER_RANGE& aLayer ) const
+{
+    LAYER_RANGE test = aItem->Layers().Intersection( aLayer );
+
+    if( aItem->Parent() )
+    {
+        switch( aItem->Parent()->Type() )
+        {
+        case PCB_VIA_T:
+        {
+            const PCB_VIA* via = static_cast<const PCB_VIA*>( aItem->Parent() );
+
+            for( int layer = test.Start(); layer <= test.End(); ++layer )
+            {
+                if( via->FlashLayer( ToLAYER_ID( layer ) ) )
+                    return true;
+            }
+
+            return false;
+        }
+
+        case PCB_PAD_T:
+        {
+            const PAD* pad = static_cast<const PAD*>( aItem->Parent() );
+
+            for( int layer = test.Start(); layer <= test.End(); ++layer )
+            {
+                if( pad->FlashLayer( ToLAYER_ID( layer ) ) )
+                    return true;
+            }
+
+            return false;
+        }
+
+        default:
+            break;
+        }
+    }
+
+    return test.Start() <= test.End();
+}
+
+
 bool PNS_KICAD_IFACE::IsItemVisible( const PNS::ITEM* aItem ) const
 {
     // by default, all items are visible (new ones created by the router have parent == NULL
