@@ -815,42 +815,73 @@ void ZONE_FILLER::addHoleKnockout( PAD* aPad, int aGap, SHAPE_POLY_SET& aHoles )
 void ZONE_FILLER::addKnockout( BOARD_ITEM* aItem, PCB_LAYER_ID aLayer, int aGap,
                                bool aIgnoreLineWidth, SHAPE_POLY_SET& aHoles )
 {
-    EDA_TEXT* text = nullptr;
-
     switch( aItem->Type() )
     {
-    case PCB_TEXT_T:       text = static_cast<PCB_TEXT*>( aItem );    break;
-    case PCB_TEXTBOX_T:    text = static_cast<PCB_TEXTBOX*>( aItem ); break;
-    case PCB_FP_TEXT_T:    text = static_cast<FP_TEXT*>( aItem );     break;
-    case PCB_FP_TEXTBOX_T: text = static_cast<FP_TEXTBOX*>( aItem );  break;
-    default:                                                          break;
-    }
-
-    if( text )
-        aGap += GetKnockoutTextMargin( text->GetTextSize(), text->GetTextThickness() );
-
-    switch( aItem->Type() )
-    {
-    case PCB_SHAPE_T:
-    case PCB_TEXT_T:
-    case PCB_TEXTBOX_T:
-    case PCB_FP_TEXTBOX_T:
-    case PCB_FP_SHAPE_T:
-    case PCB_TARGET_T:
-        aItem->TransformShapeToPolygon( aHoles, aLayer, aGap, m_maxError, ERROR_OUTSIDE,
-                                        aIgnoreLineWidth );
-        break;
-
     case PCB_FP_TEXT_T:
+    {
+        FP_TEXT* text = static_cast<FP_TEXT*>( aItem );
+
         if( text->IsVisible() )
         {
-            aItem->TransformShapeToPolygon( aHoles, aLayer, aGap, m_maxError, ERROR_OUTSIDE,
-                                            aIgnoreLineWidth );
+            if( text->IsKnockout() )
+            {
+                int antiGap = -m_maxError * 2;   // Don't leave gaps around knockout text
+                text->TransformShapeToPolygon( aHoles, aLayer, antiGap, m_maxError, ERROR_OUTSIDE,
+                                               aIgnoreLineWidth );
+            }
+            else
+            {
+                text->TransformShapeToPolygon( aHoles, aLayer, aGap, m_maxError, ERROR_OUTSIDE,
+                                               aIgnoreLineWidth );
+            }
         }
 
         break;
+    }
+
+    case PCB_TEXT_T:
+    {
+        PCB_TEXT* text = static_cast<PCB_TEXT*>( aItem );
+
+        if( text->IsVisible() )
+        {
+            if( text->IsKnockout() )
+            {
+                int antiGap = -m_maxError * 2;   // Don't leave gaps around knockout text
+                text->TransformShapeToPolygon( aHoles, aLayer, antiGap, m_maxError, ERROR_OUTSIDE );
+            }
+            else
+            {
+                text->TransformShapeToPolygon( aHoles, aLayer, aGap, m_maxError, ERROR_OUTSIDE );
+            }
+        }
+
+        break;
+    }
+
+    case PCB_FP_TEXTBOX_T:
+    {
+        FP_TEXTBOX* textbox = static_cast<FP_TEXTBOX*>( aItem );
+
+        if( textbox->IsVisible() )
+            textbox->TransformShapeToPolygon( aHoles, aLayer, aGap, m_maxError, ERROR_OUTSIDE );
+
+        break;
+    }
+
+    case PCB_TEXTBOX_T:
+    {
+        PCB_TEXTBOX* textbox = static_cast<PCB_TEXTBOX*>( aItem );
+
+        if( textbox->IsVisible() )
+            textbox->TransformShapeToPolygon( aHoles, aLayer, aGap, m_maxError, ERROR_OUTSIDE );
+
+        break;
+    }
 
     default:
+        aItem->TransformShapeToPolygon( aHoles, aLayer, aGap, m_maxError, ERROR_OUTSIDE,
+                                        aIgnoreLineWidth );
         break;
     }
 }
@@ -1557,7 +1588,7 @@ bool ZONE_FILLER::fillCopperZone( const ZONE* aZone, PCB_LAYER_ID aLayer, PCB_LA
      */
 
     if( half_min_width - epsilon > epsilon )
-        aFillPolys.Inflate( half_min_width - epsilon, numSegs, cornerStrategy );
+        aFillPolys.Inflate( half_min_width - epsilon, numSegs, cornerStrategy, true );
 
     DUMP_POLYS_TO_COPPER_LAYER( aFillPolys, In15_Cu, wxT( "after-reinflating" ) );
 
